@@ -28,6 +28,7 @@
 struct _ValaCCodeConstantPrivate {
 	char* _name;
 };
+
 #define VALA_CCODE_CONSTANT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_CONSTANT, ValaCCodeConstantPrivate))
 enum  {
 	VALA_CCODE_CONSTANT_DUMMY_PROPERTY,
@@ -43,6 +44,7 @@ ValaCCodeConstant* vala_ccode_constant_new (const char* _name) {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaCCodeConstant * self;
+	g_return_val_if_fail (_name != NULL, NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
 	__params_it->name = "name";
@@ -62,7 +64,7 @@ ValaCCodeConstant* vala_ccode_constant_new (const char* _name) {
 static void vala_ccode_constant_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeConstant * self;
 	self = VALA_CCODE_CONSTANT (base);
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_string (writer, self->priv->_name);
 }
 
