@@ -1,6 +1,6 @@
 /* valaccodedeclaration.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -26,12 +26,17 @@
 #include <gee/collection.h>
 #include <ccode/valaccodenode.h>
 #include <ccode/valaccodelinedirective.h>
+#include <ccode/valaccodevariabledeclarator.h>
+
+
+
 
 struct _ValaCCodeDeclarationPrivate {
 	char* _type_name;
 	ValaCCodeModifiers _modifiers;
 	GeeList* declarators;
 };
+
 #define VALA_CCODE_DECLARATION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_DECLARATION, ValaCCodeDeclarationPrivate))
 enum  {
 	VALA_CCODE_DECLARATION_DUMMY_PROPERTY,
@@ -39,13 +44,16 @@ enum  {
 	VALA_CCODE_DECLARATION_MODIFIERS
 };
 static void vala_ccode_declaration_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
+static gboolean vala_ccode_declaration_has_initializer (ValaCCodeDeclaration* self);
 static void vala_ccode_declaration_real_write_declaration (ValaCCodeNode* base, ValaCCodeWriter* writer);
 static gpointer vala_ccode_declaration_parent_class = NULL;
 static void vala_ccode_declaration_dispose (GObject * obj);
 
 
+
 ValaCCodeDeclaration* vala_ccode_declaration_new (const char* type_name) {
 	ValaCCodeDeclaration * self;
+	g_return_val_if_fail (type_name != NULL, NULL);
 	self = g_object_newv (VALA_TYPE_CCODE_DECLARATION, 0, NULL);
 	vala_ccode_declaration_set_type_name (self, type_name);
 	return self;
@@ -59,7 +67,7 @@ ValaCCodeDeclaration* vala_ccode_declaration_new (const char* type_name) {
  */
 void vala_ccode_declaration_add_declarator (ValaCCodeDeclaration* self, ValaCCodeDeclarator* decl) {
 	g_return_if_fail (VALA_IS_CCODE_DECLARATION (self));
-	g_return_if_fail (decl == NULL || VALA_IS_CCODE_DECLARATOR (decl));
+	g_return_if_fail (VALA_IS_CCODE_DECLARATOR (decl));
 	gee_collection_add (GEE_COLLECTION (self->priv->declarators), decl);
 }
 
@@ -67,15 +75,18 @@ void vala_ccode_declaration_add_declarator (ValaCCodeDeclaration* self, ValaCCod
 static void vala_ccode_declaration_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeDeclaration * self;
 	self = VALA_CCODE_DECLARATION (base);
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
-	if ((vala_ccode_declaration_get_modifiers (self) & (VALA_CCODE_MODIFIERS_STATIC | VALA_CCODE_MODIFIERS_EXTERN)) != 0) {
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
+	if ((self->priv->_modifiers & (VALA_CCODE_MODIFIERS_STATIC | VALA_CCODE_MODIFIERS_EXTERN)) != 0) {
 		gboolean first;
 		/* combined declaration and initialization for static and extern variables*/
 		vala_ccode_writer_write_indent (writer, vala_ccode_node_get_line (VALA_CCODE_NODE (self)));
-		if ((vala_ccode_declaration_get_modifiers (self) & VALA_CCODE_MODIFIERS_STATIC) != 0) {
+		if ((self->priv->_modifiers & VALA_CCODE_MODIFIERS_STATIC) != 0) {
 			vala_ccode_writer_write_string (writer, "static ");
 		}
-		vala_ccode_writer_write_string (writer, vala_ccode_declaration_get_type_name (self));
+		if ((self->priv->_modifiers & VALA_CCODE_MODIFIERS_EXTERN) != 0 && !vala_ccode_declaration_has_initializer (self)) {
+			vala_ccode_writer_write_string (writer, "extern ");
+		}
+		vala_ccode_writer_write_string (writer, self->priv->_type_name);
 		vala_ccode_writer_write_string (writer, " ");
 		first = TRUE;
 		{
@@ -120,20 +131,51 @@ static void vala_ccode_declaration_real_write (ValaCCodeNode* base, ValaCCodeWri
 }
 
 
+static gboolean vala_ccode_declaration_has_initializer (ValaCCodeDeclaration* self) {
+	g_return_val_if_fail (VALA_IS_CCODE_DECLARATION (self), FALSE);
+	{
+		GeeList* decl_collection;
+		GeeIterator* decl_it;
+		decl_collection = self->priv->declarators;
+		decl_it = gee_iterable_iterator (GEE_ITERABLE (decl_collection));
+		while (gee_iterator_next (decl_it)) {
+			ValaCCodeDeclarator* decl;
+			decl = ((ValaCCodeDeclarator*) gee_iterator_get (decl_it));
+			{
+				ValaCCodeVariableDeclarator* _tmp1;
+				ValaCCodeDeclarator* _tmp0;
+				ValaCCodeVariableDeclarator* var_decl;
+				_tmp1 = NULL;
+				_tmp0 = NULL;
+				var_decl = (_tmp1 = (_tmp0 = decl, (VALA_IS_CCODE_VARIABLE_DECLARATOR (_tmp0) ? ((ValaCCodeVariableDeclarator*) _tmp0) : NULL)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
+				if (var_decl != NULL && vala_ccode_variable_declarator_get_initializer (var_decl) == NULL) {
+					gboolean _tmp2;
+					return (_tmp2 = FALSE, (decl == NULL ? NULL : (decl = (g_object_unref (decl), NULL))), (var_decl == NULL ? NULL : (var_decl = (g_object_unref (var_decl), NULL))), (decl_it == NULL ? NULL : (decl_it = (g_object_unref (decl_it), NULL))), _tmp2);
+				}
+				(decl == NULL ? NULL : (decl = (g_object_unref (decl), NULL)));
+				(var_decl == NULL ? NULL : (var_decl = (g_object_unref (var_decl), NULL)));
+			}
+		}
+		(decl_it == NULL ? NULL : (decl_it = (g_object_unref (decl_it), NULL)));
+	}
+	return TRUE;
+}
+
+
 static void vala_ccode_declaration_real_write_declaration (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeDeclaration * self;
 	gboolean first;
 	self = VALA_CCODE_DECLARATION (base);
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
-	if ((vala_ccode_declaration_get_modifiers (self) & (VALA_CCODE_MODIFIERS_STATIC | VALA_CCODE_MODIFIERS_EXTERN)) != 0) {
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
+	if ((self->priv->_modifiers & (VALA_CCODE_MODIFIERS_STATIC | VALA_CCODE_MODIFIERS_EXTERN)) != 0) {
+		/* no separate declaration for static variables*/
 		return;
 	}
-	/* no separate declaration for static variables*/
 	vala_ccode_writer_write_indent (writer, NULL);
-	if ((vala_ccode_declaration_get_modifiers (self) & VALA_CCODE_MODIFIERS_REGISTER) == VALA_CCODE_MODIFIERS_REGISTER) {
+	if ((self->priv->_modifiers & VALA_CCODE_MODIFIERS_REGISTER) == VALA_CCODE_MODIFIERS_REGISTER) {
 		vala_ccode_writer_write_string (writer, "register ");
 	}
-	vala_ccode_writer_write_string (writer, vala_ccode_declaration_get_type_name (self));
+	vala_ccode_writer_write_string (writer, self->priv->_type_name);
 	vala_ccode_writer_write_string (writer, " ");
 	first = TRUE;
 	{
@@ -197,7 +239,7 @@ static void vala_ccode_declaration_get_property (GObject * object, guint propert
 		g_value_set_string (value, vala_ccode_declaration_get_type_name (self));
 		break;
 		case VALA_CCODE_DECLARATION_MODIFIERS:
-		g_value_set_int (value, vala_ccode_declaration_get_modifiers (self));
+		g_value_set_flags (value, vala_ccode_declaration_get_modifiers (self));
 		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -214,7 +256,7 @@ static void vala_ccode_declaration_set_property (GObject * object, guint propert
 		vala_ccode_declaration_set_type_name (self, g_value_get_string (value));
 		break;
 		case VALA_CCODE_DECLARATION_MODIFIERS:
-		vala_ccode_declaration_set_modifiers (self, g_value_get_int (value));
+		vala_ccode_declaration_set_modifiers (self, g_value_get_flags (value));
 		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -232,7 +274,7 @@ static void vala_ccode_declaration_class_init (ValaCCodeDeclarationClass * klass
 	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_declaration_real_write;
 	VALA_CCODE_NODE_CLASS (klass)->write_declaration = vala_ccode_declaration_real_write_declaration;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_DECLARATION_TYPE_NAME, g_param_spec_string ("type-name", "type-name", "type-name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_DECLARATION_MODIFIERS, g_param_spec_int ("modifiers", "modifiers", "modifiers", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_DECLARATION_MODIFIERS, g_param_spec_flags ("modifiers", "modifiers", "modifiers", VALA_TYPE_CCODE_MODIFIERS, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
