@@ -22,11 +22,15 @@
 
 #include <ccode/valaccodeformalparameter.h>
 
+
+
+
 struct _ValaCCodeFormalParameterPrivate {
 	char* _name;
 	char* _type_name;
 	gboolean _ellipsis;
 };
+
 #define VALA_CCODE_FORMAL_PARAMETER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_FORMAL_PARAMETER, ValaCCodeFormalParameterPrivate))
 enum  {
 	VALA_CCODE_FORMAL_PARAMETER_DUMMY_PROPERTY,
@@ -39,8 +43,11 @@ static gpointer vala_ccode_formal_parameter_parent_class = NULL;
 static void vala_ccode_formal_parameter_dispose (GObject * obj);
 
 
+
 ValaCCodeFormalParameter* vala_ccode_formal_parameter_new (const char* n, const char* type) {
 	ValaCCodeFormalParameter * self;
+	g_return_val_if_fail (n != NULL, NULL);
+	g_return_val_if_fail (type != NULL, NULL);
 	self = g_object_newv (VALA_TYPE_CCODE_FORMAL_PARAMETER, 0, NULL);
 	vala_ccode_formal_parameter_set_name (self, n);
 	vala_ccode_formal_parameter_set_type_name (self, type);
@@ -59,11 +66,11 @@ ValaCCodeFormalParameter* vala_ccode_formal_parameter_new_with_ellipsis (void) {
 static void vala_ccode_formal_parameter_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeFormalParameter * self;
 	self = VALA_CCODE_FORMAL_PARAMETER (base);
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
-	if (!vala_ccode_formal_parameter_get_ellipsis (self)) {
-		vala_ccode_writer_write_string (writer, vala_ccode_formal_parameter_get_type_name (self));
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
+	if (!self->priv->_ellipsis) {
+		vala_ccode_writer_write_string (writer, self->priv->_type_name);
 		vala_ccode_writer_write_string (writer, " ");
-		vala_ccode_writer_write_string (writer, vala_ccode_formal_parameter_get_name (self));
+		vala_ccode_writer_write_string (writer, self->priv->_name);
 	} else {
 		vala_ccode_writer_write_string (writer, "...");
 	}
@@ -175,8 +182,8 @@ static void vala_ccode_formal_parameter_init (ValaCCodeFormalParameter * self) {
 static void vala_ccode_formal_parameter_dispose (GObject * obj) {
 	ValaCCodeFormalParameter * self;
 	self = VALA_CCODE_FORMAL_PARAMETER (obj);
-	(self->priv->_name = (g_free (self->priv->_name), NULL));
-	(self->priv->_type_name = (g_free (self->priv->_type_name), NULL));
+	self->priv->_name = (g_free (self->priv->_name), NULL);
+	self->priv->_type_name = (g_free (self->priv->_type_name), NULL);
 	G_OBJECT_CLASS (vala_ccode_formal_parameter_parent_class)->dispose (obj);
 }
 
