@@ -29,6 +29,7 @@
 struct _ValaCCodeGotoStatementPrivate {
 	char* _name;
 };
+
 #define VALA_CCODE_GOTO_STATEMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_GOTO_STATEMENT, ValaCCodeGotoStatementPrivate))
 enum  {
 	VALA_CCODE_GOTO_STATEMENT_DUMMY_PROPERTY,
@@ -44,6 +45,7 @@ ValaCCodeGotoStatement* vala_ccode_goto_statement_new (const char* name) {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaCCodeGotoStatement * self;
+	g_return_val_if_fail (name != NULL, NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
 	__params_it->name = "name";
@@ -63,7 +65,7 @@ ValaCCodeGotoStatement* vala_ccode_goto_statement_new (const char* name) {
 static void vala_ccode_goto_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeGotoStatement * self;
 	self = VALA_CCODE_GOTO_STATEMENT (base);
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_indent (writer, NULL);
 	vala_ccode_writer_write_string (writer, "goto ");
 	vala_ccode_writer_write_string (writer, self->priv->_name);
