@@ -22,12 +22,26 @@
 
 #include <ccode/valaccodestatement.h>
 
+
+
+
 enum  {
 	VALA_CCODE_STATEMENT_DUMMY_PROPERTY
 };
 static gpointer vala_ccode_statement_parent_class = NULL;
 
 
+
+/**
+ * Represents a statement in the C code.
+ */
+ValaCCodeStatement* vala_ccode_statement_new (void) {
+	ValaCCodeStatement * self;
+	self = g_object_newv (VALA_TYPE_CCODE_STATEMENT, 0, NULL);
+	return self;
+}
+
+
 static void vala_ccode_statement_class_init (ValaCCodeStatementClass * klass) {
 	vala_ccode_statement_parent_class = g_type_class_peek_parent (klass);
 }
