@@ -37,6 +37,7 @@ struct _ValaCCodeSwitchStatementPrivate {
 	GeeList* case_statements;
 	GeeList* default_statements;
 };
+
 #define VALA_CCODE_SWITCH_STATEMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_SWITCH_STATEMENT, ValaCCodeSwitchStatementPrivate))
 enum  {
 	VALA_CCODE_SWITCH_STATEMENT_DUMMY_PROPERTY,
@@ -50,7 +51,7 @@ static void vala_ccode_switch_statement_dispose (GObject * obj);
 
 ValaCCodeSwitchStatement* vala_ccode_switch_statement_new (ValaCCodeExpression* expression) {
 	ValaCCodeSwitchStatement * self;
-	g_return_val_if_fail (expression == NULL || VALA_IS_CCODE_EXPRESSION (expression), NULL);
+	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (expression), NULL);
 	self = g_object_newv (VALA_TYPE_CCODE_SWITCH_STATEMENT, 0, NULL);
 	vala_ccode_switch_statement_set_expression (self, expression);
 	return self;
@@ -64,7 +65,7 @@ ValaCCodeSwitchStatement* vala_ccode_switch_statement_new (ValaCCodeExpression*
  */
 void vala_ccode_switch_statement_add_case (ValaCCodeSwitchStatement* self, ValaCCodeCaseStatement* case_stmt) {
 	g_return_if_fail (VALA_IS_CCODE_SWITCH_STATEMENT (self));
-	g_return_if_fail (case_stmt == NULL || VALA_IS_CCODE_CASE_STATEMENT (case_stmt));
+	g_return_if_fail (VALA_IS_CCODE_CASE_STATEMENT (case_stmt));
 	gee_collection_add (GEE_COLLECTION (self->priv->case_statements), case_stmt);
 }
 
@@ -76,7 +77,7 @@ void vala_ccode_switch_statement_add_case (ValaCCodeSwitchStatement* self, ValaC
  */
 void vala_ccode_switch_statement_add_default_statement (ValaCCodeSwitchStatement* self, ValaCCodeStatement* stmt) {
 	g_return_if_fail (VALA_IS_CCODE_SWITCH_STATEMENT (self));
-	g_return_if_fail (stmt == NULL || VALA_IS_CCODE_STATEMENT (stmt));
+	g_return_if_fail (VALA_IS_CCODE_STATEMENT (stmt));
 	gee_collection_add (GEE_COLLECTION (self->priv->default_statements), stmt);
 }
 
@@ -84,7 +85,7 @@ void vala_ccode_switch_statement_add_default_statement (ValaCCodeSwitchStatement
 static void vala_ccode_switch_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
 	ValaCCodeSwitchStatement * self;
 	self = VALA_CCODE_SWITCH_STATEMENT (base);
-	g_return_if_fail (writer == NULL || VALA_IS_CCODE_WRITER (writer));
+	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
 	vala_ccode_writer_write_indent (writer, vala_ccode_node_get_line (VALA_CCODE_NODE (self)));
 	vala_ccode_writer_write_string (writer, "switch (");
 	vala_ccode_node_write (VALA_CCODE_NODE (self->priv->_expression), writer);
