@@ -76,36 +76,45 @@ struct _GeeHashMapNode {
 	GeeHashMapNode* next;
 	guint key_hash;
 };
+
 struct _GeeHashMapKeySet {
 	GObject parent_instance;
 	GeeHashMapKeySetPrivate * priv;
 };
+
 struct _GeeHashMapKeySetClass {
 	GObjectClass parent_class;
 };
+
 struct _GeeHashMapKeyIterator {
 	GObject parent_instance;
 	GeeHashMapKeyIteratorPrivate * priv;
 };
+
 struct _GeeHashMapKeyIteratorClass {
 	GObjectClass parent_class;
 };
+
 struct _GeeHashMapValueCollection {
 	GObject parent_instance;
 	GeeHashMapValueCollectionPrivate * priv;
 };
+
 struct _GeeHashMapValueCollectionClass {
 	GObjectClass parent_class;
 };
+
 struct _GeeHashMapValueIterator {
 	GObject parent_instance;
 	GeeHashMapValueIteratorPrivate * priv;
 };
+
 struct _GeeHashMapValueIteratorClass {
 	GObjectClass parent_class;
 };
 
 
+
 struct _GeeHashMapPrivate {
 	gint _array_size;
 	gint _nnodes;
@@ -122,6 +131,7 @@ struct _GeeHashMapPrivate {
 	GBoxedCopyFunc v_dup_func;
 	GDestroyNotify v_destroy_func;
 };
+
 #define GEE_HASH_MAP_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GEE_TYPE_HASH_MAP, GeeHashMapPrivate))
 enum  {
 	GEE_HASH_MAP_DUMMY_PROPERTY,
@@ -157,6 +167,7 @@ struct _GeeHashMapKeySetPrivate {
 	GBoxedCopyFunc v_dup_func;
 	GDestroyNotify v_destroy_func;
 };
+
 #define GEE_HASH_MAP_KEY_SET_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GEE_HASH_MAP_TYPE_KEY_SET, GeeHashMapKeySetPrivate))
 enum  {
 	GEE_HASH_MAP_KEY_SET_DUMMY_PROPERTY,
@@ -195,6 +206,7 @@ struct _GeeHashMapKeyIteratorPrivate {
 	GBoxedCopyFunc v_dup_func;
 	GDestroyNotify v_destroy_func;
 };
+
 #define GEE_HASH_MAP_KEY_ITERATOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GEE_HASH_MAP_TYPE_KEY_ITERATOR, GeeHashMapKeyIteratorPrivate))
 enum  {
 	GEE_HASH_MAP_KEY_ITERATOR_DUMMY_PROPERTY,
@@ -223,6 +235,7 @@ struct _GeeHashMapValueCollectionPrivate {
 	GBoxedCopyFunc v_dup_func;
 	GDestroyNotify v_destroy_func;
 };
+
 #define GEE_HASH_MAP_VALUE_COLLECTION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GEE_HASH_MAP_TYPE_VALUE_COLLECTION, GeeHashMapValueCollectionPrivate))
 enum  {
 	GEE_HASH_MAP_VALUE_COLLECTION_DUMMY_PROPERTY,
@@ -260,6 +273,7 @@ struct _GeeHashMapValueIteratorPrivate {
 	GBoxedCopyFunc v_dup_func;
 	GDestroyNotify v_destroy_func;
 };
+
 #define GEE_HASH_MAP_VALUE_ITERATOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GEE_HASH_MAP_TYPE_VALUE_ITERATOR, GeeHashMapValueIteratorPrivate))
 enum  {
 	GEE_HASH_MAP_VALUE_ITERATOR_DUMMY_PROPERTY,
@@ -289,17 +303,44 @@ static const gint GEE_HASH_MAP_MAX_SIZE = 13845163;
 
 
 GeeHashMap* gee_hash_map_new (GType k_type, GBoxedCopyFunc k_dup_func, GDestroyNotify k_destroy_func, GType v_type, GBoxedCopyFunc v_dup_func, GDestroyNotify v_destroy_func, GHashFunc key_hash_func, GEqualFunc key_equal_func, GEqualFunc value_equal_func) {
+	GParameter * __params;
+	GParameter * __params_it;
 	GeeHashMap * self;
-	self = g_object_newv (GEE_TYPE_HASH_MAP, 0, NULL);
+	__params = g_new0 (GParameter, 6);
+	__params_it = __params;
+	__params_it->name = "k-type";
+	g_value_init (&__params_it->value, G_TYPE_GTYPE);
+	g_value_set_gtype (&__params_it->value, k_type);
+	__params_it++;
+	__params_it->name = "k-dup-func";
+	g_value_init (&__params_it->value, G_TYPE_POINTER);
+	g_value_set_pointer (&__params_it->value, k_dup_func);
+	__params_it++;
+	__params_it->name = "k-destroy-func";
+	g_value_init (&__params_it->value, G_TYPE_POINTER);
+	g_value_set_pointer (&__params_it->value, k_destroy_func);
+	__params_it++;
+	__params_it->name = "v-type";
+	g_value_init (&__params_it->value, G_TYPE_GTYPE);
+	g_value_set_gtype (&__params_it->value, v_type);
+	__params_it++;
+	__params_it->name = "v-dup-func";
+	g_value_init (&__params_it->value, G_TYPE_POINTER);
+	g_value_set_pointer (&__params_it->value, v_dup_func);
+	__params_it++;
+	__params_it->name = "v-destroy-func";
+	g_value_init (&__params_it->value, G_TYPE_POINTER);
+	g_value_set_pointer (&__params_it->value, v_destroy_func);
+	__params_it++;
+	self = g_object_newv (GEE_TYPE_HASH_MAP, __params_it - __params, __params);
 	gee_hash_map_set_key_hash_func (self, key_hash_func);
 	gee_hash_map_set_key_equal_func (self, key_equal_func);
 	gee_hash_map_set_value_equal_func (self, value_equal_func);
-	self->priv->k_type = k_type;
-	self->priv->k_dup_func = k_dup_func;
-	self->priv->k_destroy_func = k_destroy_func;
-	self->priv->v_type = v_type;
-	self->priv->v_dup_func = v_dup_func;
-	self->priv->v_destroy_func = v_destroy_func;
+	while (__params_it > __params) {
+		--__params_it;
+		g_value_unset (&__params_it->value);
+	}
+	g_free (__params);
 	return self;
 }
 
@@ -409,7 +450,7 @@ static void gee_hash_map_real_clear (GeeMap* base) {
 	{
 		gint i;
 		i = 0;
-		for (i = 0; i < self->priv->_array_size; i++) {
+		for (; i < self->priv->_array_size; i++) {
 			GeeHashMapNode* _tmp0;
 			GeeHashMapNode* node;
 			_tmp0 = NULL;
@@ -456,7 +497,7 @@ static void gee_hash_map_resize (GeeHashMap* self) {
 		{
 			gint i;
 			i = 0;
-			for (i = 0; i < self->priv->_array_size; i++) {
+			for (; i < self->priv->_array_size; i++) {
 				GeeHashMapNode* node;
 				GeeHashMapNode* next;
 				GeeHashMapNode* _tmp4;
@@ -571,16 +612,43 @@ static void gee_hash_map_node_free (GeeHashMapNode* self) {
 
 
 static GeeHashMapKeySet* gee_hash_map_key_set_new (GType k_type, GBoxedCopyFunc k_dup_func, GDestroyNotify k_destroy_func, GType v_type, GBoxedCopyFunc v_dup_func, GDestroyNotify v_destroy_func, GeeHashMap* map) {
+	GParameter * __params;
+	GParameter * __params_it;
 	GeeHashMapKeySet * self;
-	g_return_val_if_fail (map == NULL || GEE_IS_HASH_MAP (map), NULL);
-	self = g_object_newv (GEE_HASH_MAP_TYPE_KEY_SET, 0, NULL);
+	g_return_val_if_fail (GEE_IS_HASH_MAP (map), NULL);
+	__params = g_new0 (GParameter, 6);
+	__params_it = __params;
+	__params_it->name = "k-type";
+	g_value_init (&__params_it->value, G_TYPE_GTYPE);
+	g_value_set_gtype (&__params_it->value, k_type);
+	__params_it++;
+	__params_it->name = "k-dup-func";
+	g_value_init (&__params_it->value, G_TYPE_POINTER);
+	g_value_set_pointer (&__params_it->value, k_dup_func);
+	__params_it++;
+	__params_it->name = "k-destroy-func";
+	g_value_init (&__params_it->value, G_TYPE_POINTER);
+	g_value_set_pointer (&__params_it->value, k_destroy_func);
+	__params_it++;
+	__params_it->name = "v-type";
+	g_value_init (&__params_it->value, G_TYPE_GTYPE);
+	g_value_set_gtype (&__params_it->value, v_type);
+	__params_it++;
+	__params_it->name = "v-dup-func";
+	g_value_init (&__params_it->value, G_TYPE_POINTER);
+	g_value_set_pointer (&__params_it->value, v_dup_func);
+	__params_it++;
+	__params_it->name = "v-destroy-func";
+	g_value_init (&__params_it->value, G_TYPE_POINTER);
+	g_value_set_pointer (&__params_it->value, v_destroy_func);
+	__params_it++;
+	self = g_object_newv (GEE_HASH_MAP_TYPE_KEY_SET, __params_it - __params, __params);
 	gee_hash_map_key_set_set_map (self, map);
-	self->priv->k_type = k_type;
-	self->priv->k_dup_func = k_dup_func;
-	self->priv->k_destroy_func = k_destroy_func;
-	self->priv->v_type = v_type;
-	self->priv->v_dup_func = v_dup_func;
-	self->priv->v_destroy_func = v_destroy_func;
+	while (__params_it > __params) {
+		--__params_it;
+		g_value_unset (&__params_it->value);
+	}
+	g_free (__params);
 	return self;
 }
 
@@ -695,12 +763,12 @@ static void gee_hash_map_key_set_class_init (GeeHashMapKeySetClass * klass) {
 	G_OBJECT_CLASS (klass)->get_property = gee_hash_map_key_set_get_property;
 	G_OBJECT_CLASS (klass)->set_property = gee_hash_map_key_set_set_property;
 	G_OBJECT_CLASS (klass)->dispose = gee_hash_map_key_set_dispose;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_KEY_SET_K_TYPE, g_param_spec_gtype ("k-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_KEY_SET_K_DUP_FUNC, g_param_spec_pointer ("k-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_KEY_SET_K_DESTROY_FUNC, g_param_spec_pointer ("k-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_KEY_SET_V_TYPE, g_param_spec_gtype ("v-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_KEY_SET_V_DUP_FUNC, g_param_spec_pointer ("v-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_KEY_SET_V_DESTROY_FUNC, g_param_spec_pointer ("v-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_KEY_SET_K_TYPE, g_param_spec_gtype ("k-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_KEY_SET_K_DUP_FUNC, g_param_spec_pointer ("k-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_KEY_SET_K_DESTROY_FUNC, g_param_spec_pointer ("k-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_KEY_SET_V_TYPE, g_param_spec_gtype ("v-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_KEY_SET_V_DUP_FUNC, g_param_spec_pointer ("v-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_KEY_SET_V_DESTROY_FUNC, g_param_spec_pointer ("v-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_KEY_SET_MAP, g_param_spec_object ("map", "map", "map", GEE_TYPE_HASH_MAP, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
 	g_object_class_override_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_KEY_SET_SIZE, "size");
 }
@@ -757,16 +825,43 @@ static GType gee_hash_map_key_set_get_type (void) {
 
 
 static GeeHashMapKeyIterator* gee_hash_map_key_iterator_new (GType k_type, GBoxedCopyFunc k_dup_func, GDestroyNotify k_destroy_func, GType v_type, GBoxedCopyFunc v_dup_func, GDestroyNotify v_destroy_func, GeeHashMap* map) {
+	GParameter * __params;
+	GParameter * __params_it;
 	GeeHashMapKeyIterator * self;
-	g_return_val_if_fail (map == NULL || GEE_IS_HASH_MAP (map), NULL);
-	self = g_object_newv (GEE_HASH_MAP_TYPE_KEY_ITERATOR, 0, NULL);
+	g_return_val_if_fail (GEE_IS_HASH_MAP (map), NULL);
+	__params = g_new0 (GParameter, 6);
+	__params_it = __params;
+	__params_it->name = "k-type";
+	g_value_init (&__params_it->value, G_TYPE_GTYPE);
+	g_value_set_gtype (&__params_it->value, k_type);
+	__params_it++;
+	__params_it->name = "k-dup-func";
+	g_value_init (&__params_it->value, G_TYPE_POINTER);
+	g_value_set_pointer (&__params_it->value, k_dup_func);
+	__params_it++;
+	__params_it->name = "k-destroy-func";
+	g_value_init (&__params_it->value, G_TYPE_POINTER);
+	g_value_set_pointer (&__params_it->value, k_destroy_func);
+	__params_it++;
+	__params_it->name = "v-type";
+	g_value_init (&__params_it->value, G_TYPE_GTYPE);
+	g_value_set_gtype (&__params_it->value, v_type);
+	__params_it++;
+	__params_it->name = "v-dup-func";
+	g_value_init (&__params_it->value, G_TYPE_POINTER);
+	g_value_set_pointer (&__params_it->value, v_dup_func);
+	__params_it++;
+	__params_it->name = "v-destroy-func";
+	g_value_init (&__params_it->value, G_TYPE_POINTER);
+	g_value_set_pointer (&__params_it->value, v_destroy_func);
+	__params_it++;
+	self = g_object_newv (GEE_HASH_MAP_TYPE_KEY_ITERATOR, __params_it - __params, __params);
 	gee_hash_map_key_iterator_set_map (self, map);
-	self->priv->k_type = k_type;
-	self->priv->k_dup_func = k_dup_func;
-	self->priv->k_destroy_func = k_destroy_func;
-	self->priv->v_type = v_type;
-	self->priv->v_dup_func = v_dup_func;
-	self->priv->v_destroy_func = v_destroy_func;
+	while (__params_it > __params) {
+		--__params_it;
+		g_value_unset (&__params_it->value);
+	}
+	g_free (__params);
 	return self;
 }
 
@@ -856,12 +951,12 @@ static void gee_hash_map_key_iterator_class_init (GeeHashMapKeyIteratorClass * k
 	G_OBJECT_CLASS (klass)->get_property = gee_hash_map_key_iterator_get_property;
 	G_OBJECT_CLASS (klass)->set_property = gee_hash_map_key_iterator_set_property;
 	G_OBJECT_CLASS (klass)->dispose = gee_hash_map_key_iterator_dispose;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_KEY_ITERATOR_K_TYPE, g_param_spec_gtype ("k-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_KEY_ITERATOR_K_DUP_FUNC, g_param_spec_pointer ("k-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_KEY_ITERATOR_K_DESTROY_FUNC, g_param_spec_pointer ("k-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_KEY_ITERATOR_V_TYPE, g_param_spec_gtype ("v-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_KEY_ITERATOR_V_DUP_FUNC, g_param_spec_pointer ("v-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_KEY_ITERATOR_V_DESTROY_FUNC, g_param_spec_pointer ("v-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_KEY_ITERATOR_K_TYPE, g_param_spec_gtype ("k-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_KEY_ITERATOR_K_DUP_FUNC, g_param_spec_pointer ("k-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_KEY_ITERATOR_K_DESTROY_FUNC, g_param_spec_pointer ("k-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_KEY_ITERATOR_V_TYPE, g_param_spec_gtype ("v-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_KEY_ITERATOR_V_DUP_FUNC, g_param_spec_pointer ("v-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_KEY_ITERATOR_V_DESTROY_FUNC, g_param_spec_pointer ("v-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_KEY_ITERATOR_MAP, g_param_spec_object ("map", "map", "map", GEE_TYPE_HASH_MAP, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
 }
 
@@ -900,16 +995,43 @@ static GType gee_hash_map_key_iterator_get_type (void) {
 
 
 static GeeHashMapValueCollection* gee_hash_map_value_collection_new (GType k_type, GBoxedCopyFunc k_dup_func, GDestroyNotify k_destroy_func, GType v_type, GBoxedCopyFunc v_dup_func, GDestroyNotify v_destroy_func, GeeHashMap* map) {
+	GParameter * __params;
+	GParameter * __params_it;
 	GeeHashMapValueCollection * self;
-	g_return_val_if_fail (map == NULL || GEE_IS_HASH_MAP (map), NULL);
-	self = g_object_newv (GEE_HASH_MAP_TYPE_VALUE_COLLECTION, 0, NULL);
+	g_return_val_if_fail (GEE_IS_HASH_MAP (map), NULL);
+	__params = g_new0 (GParameter, 6);
+	__params_it = __params;
+	__params_it->name = "k-type";
+	g_value_init (&__params_it->value, G_TYPE_GTYPE);
+	g_value_set_gtype (&__params_it->value, k_type);
+	__params_it++;
+	__params_it->name = "k-dup-func";
+	g_value_init (&__params_it->value, G_TYPE_POINTER);
+	g_value_set_pointer (&__params_it->value, k_dup_func);
+	__params_it++;
+	__params_it->name = "k-destroy-func";
+	g_value_init (&__params_it->value, G_TYPE_POINTER);
+	g_value_set_pointer (&__params_it->value, k_destroy_func);
+	__params_it++;
+	__params_it->name = "v-type";
+	g_value_init (&__params_it->value, G_TYPE_GTYPE);
+	g_value_set_gtype (&__params_it->value, v_type);
+	__params_it++;
+	__params_it->name = "v-dup-func";
+	g_value_init (&__params_it->value, G_TYPE_POINTER);
+	g_value_set_pointer (&__params_it->value, v_dup_func);
+	__params_it++;
+	__params_it->name = "v-destroy-func";
+	g_value_init (&__params_it->value, G_TYPE_POINTER);
+	g_value_set_pointer (&__params_it->value, v_destroy_func);
+	__params_it++;
+	self = g_object_newv (GEE_HASH_MAP_TYPE_VALUE_COLLECTION, __params_it - __params, __params);
 	gee_hash_map_value_collection_set_map (self, map);
-	self->priv->k_type = k_type;
-	self->priv->k_dup_func = k_dup_func;
-	self->priv->k_destroy_func = k_destroy_func;
-	self->priv->v_type = v_type;
-	self->priv->v_dup_func = v_dup_func;
-	self->priv->v_destroy_func = v_destroy_func;
+	while (__params_it > __params) {
+		--__params_it;
+		g_value_unset (&__params_it->value);
+	}
+	g_free (__params);
 	return self;
 }
 
@@ -1036,12 +1158,12 @@ static void gee_hash_map_value_collection_class_init (GeeHashMapValueCollectionC
 	G_OBJECT_CLASS (klass)->get_property = gee_hash_map_value_collection_get_property;
 	G_OBJECT_CLASS (klass)->set_property = gee_hash_map_value_collection_set_property;
 	G_OBJECT_CLASS (klass)->dispose = gee_hash_map_value_collection_dispose;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_VALUE_COLLECTION_K_TYPE, g_param_spec_gtype ("k-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_VALUE_COLLECTION_K_DUP_FUNC, g_param_spec_pointer ("k-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_VALUE_COLLECTION_K_DESTROY_FUNC, g_param_spec_pointer ("k-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_VALUE_COLLECTION_V_TYPE, g_param_spec_gtype ("v-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_VALUE_COLLECTION_V_DUP_FUNC, g_param_spec_pointer ("v-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_VALUE_COLLECTION_V_DESTROY_FUNC, g_param_spec_pointer ("v-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_VALUE_COLLECTION_K_TYPE, g_param_spec_gtype ("k-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_VALUE_COLLECTION_K_DUP_FUNC, g_param_spec_pointer ("k-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_VALUE_COLLECTION_K_DESTROY_FUNC, g_param_spec_pointer ("k-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_VALUE_COLLECTION_V_TYPE, g_param_spec_gtype ("v-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_VALUE_COLLECTION_V_DUP_FUNC, g_param_spec_pointer ("v-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_VALUE_COLLECTION_V_DESTROY_FUNC, g_param_spec_pointer ("v-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_VALUE_COLLECTION_MAP, g_param_spec_object ("map", "map", "map", GEE_TYPE_HASH_MAP, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
 	g_object_class_override_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_VALUE_COLLECTION_SIZE, "size");
 }
@@ -1091,16 +1213,43 @@ static GType gee_hash_map_value_collection_get_type (void) {
 
 
 static GeeHashMapValueIterator* gee_hash_map_value_iterator_new (GType k_type, GBoxedCopyFunc k_dup_func, GDestroyNotify k_destroy_func, GType v_type, GBoxedCopyFunc v_dup_func, GDestroyNotify v_destroy_func, GeeHashMap* map) {
+	GParameter * __params;
+	GParameter * __params_it;
 	GeeHashMapValueIterator * self;
-	g_return_val_if_fail (map == NULL || GEE_IS_HASH_MAP (map), NULL);
-	self = g_object_newv (GEE_HASH_MAP_TYPE_VALUE_ITERATOR, 0, NULL);
+	g_return_val_if_fail (GEE_IS_HASH_MAP (map), NULL);
+	__params = g_new0 (GParameter, 6);
+	__params_it = __params;
+	__params_it->name = "k-type";
+	g_value_init (&__params_it->value, G_TYPE_GTYPE);
+	g_value_set_gtype (&__params_it->value, k_type);
+	__params_it++;
+	__params_it->name = "k-dup-func";
+	g_value_init (&__params_it->value, G_TYPE_POINTER);
+	g_value_set_pointer (&__params_it->value, k_dup_func);
+	__params_it++;
+	__params_it->name = "k-destroy-func";
+	g_value_init (&__params_it->value, G_TYPE_POINTER);
+	g_value_set_pointer (&__params_it->value, k_destroy_func);
+	__params_it++;
+	__params_it->name = "v-type";
+	g_value_init (&__params_it->value, G_TYPE_GTYPE);
+	g_value_set_gtype (&__params_it->value, v_type);
+	__params_it++;
+	__params_it->name = "v-dup-func";
+	g_value_init (&__params_it->value, G_TYPE_POINTER);
+	g_value_set_pointer (&__params_it->value, v_dup_func);
+	__params_it++;
+	__params_it->name = "v-destroy-func";
+	g_value_init (&__params_it->value, G_TYPE_POINTER);
+	g_value_set_pointer (&__params_it->value, v_destroy_func);
+	__params_it++;
+	self = g_object_newv (GEE_HASH_MAP_TYPE_VALUE_ITERATOR, __params_it - __params, __params);
 	gee_hash_map_value_iterator_set_map (self, map);
-	self->priv->k_type = k_type;
-	self->priv->k_dup_func = k_dup_func;
-	self->priv->k_destroy_func = k_destroy_func;
-	self->priv->v_type = v_type;
-	self->priv->v_dup_func = v_dup_func;
-	self->priv->v_destroy_func = v_destroy_func;
+	while (__params_it > __params) {
+		--__params_it;
+		g_value_unset (&__params_it->value);
+	}
+	g_free (__params);
 	return self;
 }
 
@@ -1190,12 +1339,12 @@ static void gee_hash_map_value_iterator_class_init (GeeHashMapValueIteratorClass
 	G_OBJECT_CLASS (klass)->get_property = gee_hash_map_value_iterator_get_property;
 	G_OBJECT_CLASS (klass)->set_property = gee_hash_map_value_iterator_set_property;
 	G_OBJECT_CLASS (klass)->dispose = gee_hash_map_value_iterator_dispose;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_VALUE_ITERATOR_K_TYPE, g_param_spec_gtype ("k-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_VALUE_ITERATOR_K_DUP_FUNC, g_param_spec_pointer ("k-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_VALUE_ITERATOR_K_DESTROY_FUNC, g_param_spec_pointer ("k-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_VALUE_ITERATOR_V_TYPE, g_param_spec_gtype ("v-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_VALUE_ITERATOR_V_DUP_FUNC, g_param_spec_pointer ("v-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_VALUE_ITERATOR_V_DESTROY_FUNC, g_param_spec_pointer ("v-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_VALUE_ITERATOR_K_TYPE, g_param_spec_gtype ("k-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_VALUE_ITERATOR_K_DUP_FUNC, g_param_spec_pointer ("k-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_VALUE_ITERATOR_K_DESTROY_FUNC, g_param_spec_pointer ("k-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_VALUE_ITERATOR_V_TYPE, g_param_spec_gtype ("v-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_VALUE_ITERATOR_V_DUP_FUNC, g_param_spec_pointer ("v-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_VALUE_ITERATOR_V_DESTROY_FUNC, g_param_spec_pointer ("v-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_VALUE_ITERATOR_MAP, g_param_spec_object ("map", "map", "map", GEE_TYPE_HASH_MAP, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
 }
 
@@ -1292,12 +1441,12 @@ static void gee_hash_map_class_init (GeeHashMapClass * klass) {
 	G_OBJECT_CLASS (klass)->set_property = gee_hash_map_set_property;
 	G_OBJECT_CLASS (klass)->constructor = gee_hash_map_constructor;
 	G_OBJECT_CLASS (klass)->dispose = gee_hash_map_dispose;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_K_TYPE, g_param_spec_gtype ("k-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_K_DUP_FUNC, g_param_spec_pointer ("k-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_K_DESTROY_FUNC, g_param_spec_pointer ("k-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_V_TYPE, g_param_spec_gtype ("v-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_V_DUP_FUNC, g_param_spec_pointer ("v-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_V_DESTROY_FUNC, g_param_spec_pointer ("v-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_K_TYPE, g_param_spec_gtype ("k-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_K_DUP_FUNC, g_param_spec_pointer ("k-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_K_DESTROY_FUNC, g_param_spec_pointer ("k-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_V_TYPE, g_param_spec_gtype ("v-type", "type", "type", G_TYPE_NONE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_V_DUP_FUNC, g_param_spec_pointer ("v-dup-func", "dup func", "dup func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_V_DESTROY_FUNC, g_param_spec_pointer ("v-destroy-func", "destroy func", "destroy func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
 	g_object_class_override_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_SIZE, "size");
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_KEY_HASH_FUNC, g_param_spec_pointer ("key-hash-func", "key-hash-func", "key-hash-func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), GEE_HASH_MAP_KEY_EQUAL_FUNC, g_param_spec_pointer ("key-equal-func", "key-equal-func", "key-equal-func", G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
