@@ -18,7 +18,7 @@
  *
  * Author:
  * 	Jürg Billeter <j@bitron.ch>
- *	Raffaele Sandrini <rasa@gmx.ch>
+ *	Raffaele Sandrini <raffaele@sandrini.ch>
  */
 
 #ifndef __VALA_VALAATTRIBUTEPROCESSOR_H__
@@ -34,8 +34,11 @@
 #include <vala/valastruct.h>
 #include <vala/valainterface.h>
 #include <vala/valaenum.h>
+#include <vala/valaenumvalue.h>
+#include <vala/valaerrordomain.h>
 #include <vala/valamethod.h>
 #include <vala/valacreationmethod.h>
+#include <vala/valaformalparameter.h>
 #include <vala/valaproperty.h>
 #include <vala/valadelegate.h>
 #include <vala/valaconstant.h>
@@ -63,14 +66,17 @@ struct _ValaAttributeProcessor {
 	ValaCodeVisitor parent_instance;
 	ValaAttributeProcessorPrivate * priv;
 };
+
 struct _ValaAttributeProcessorClass {
 	ValaCodeVisitorClass parent_class;
 };
 
+
 void vala_attribute_processor_process (ValaAttributeProcessor* self, ValaCodeContext* context);
 ValaAttributeProcessor* vala_attribute_processor_new (void);
 GType vala_attribute_processor_get_type (void);
 
+
 G_END_DECLS
 
 #endif
