@@ -1,6 +1,6 @@
 /* valablock.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -24,7 +24,7 @@
 #include <gee/arraylist.h>
 #include <gee/list.h>
 #include <gee/readonlycollection.h>
-#include <vala/valavariabledeclarator.h>
+#include <vala/valalocalvariable.h>
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
 
@@ -36,6 +36,7 @@ struct _ValaBlockPrivate {
 	GeeList* statement_list;
 	GeeList* local_variables;
 };
+
 #define VALA_BLOCK_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_BLOCK, ValaBlockPrivate))
 enum  {
 	VALA_BLOCK_DUMMY_PROPERTY,
@@ -70,7 +71,7 @@ ValaBlock* vala_block_new (ValaSourceReference* source_reference) {
  */
 void vala_block_add_statement (ValaBlock* self, ValaStatement* stmt) {
 	g_return_if_fail (VALA_IS_BLOCK (self));
-	g_return_if_fail (stmt == NULL || VALA_IS_STATEMENT (stmt));
+	g_return_if_fail (VALA_IS_STATEMENT (stmt));
 	gee_collection_add (GEE_COLLECTION (self->priv->statement_list), stmt);
 }
 
@@ -91,10 +92,10 @@ GeeCollection* vala_block_get_statements (ValaBlock* self) {
  *
  * @param decl a variable declarator
  */
-void vala_block_add_local_variable (ValaBlock* self, ValaVariableDeclarator* decl) {
+void vala_block_add_local_variable (ValaBlock* self, ValaLocalVariable* local) {
 	g_return_if_fail (VALA_IS_BLOCK (self));
-	g_return_if_fail (decl == NULL || VALA_IS_VARIABLE_DECLARATOR (decl));
-	gee_collection_add (GEE_COLLECTION (self->priv->local_variables), decl);
+	g_return_if_fail (VALA_IS_LOCAL_VARIABLE (local));
+	gee_collection_add (GEE_COLLECTION (self->priv->local_variables), local);
 }
 
 
@@ -105,14 +106,14 @@ void vala_block_add_local_variable (ValaBlock* self, ValaVariableDeclarator* dec
  */
 GeeCollection* vala_block_get_local_variables (ValaBlock* self) {
 	g_return_val_if_fail (VALA_IS_BLOCK (self), NULL);
-	return GEE_COLLECTION (gee_read_only_collection_new (VALA_TYPE_VARIABLE_DECLARATOR, ((GBoxedCopyFunc) g_object_ref), g_object_unref, GEE_COLLECTION (self->priv->local_variables)));
+	return GEE_COLLECTION (gee_read_only_collection_new (VALA_TYPE_LOCAL_VARIABLE, ((GBoxedCopyFunc) g_object_ref), g_object_unref, GEE_COLLECTION (self->priv->local_variables)));
 }
 
 
 static void vala_block_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaBlock * self;
 	self = VALA_BLOCK (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_block (visitor, self);
 }
 
@@ -120,7 +121,7 @@ static void vala_block_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor
 static void vala_block_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaBlock * self;
 	self = VALA_BLOCK (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	{
 		GeeList* stmt_collection;
 		GeeIterator* stmt_it;
@@ -199,7 +200,7 @@ static void vala_block_vala_statement_interface_init (ValaStatementIface * iface
 static void vala_block_init (ValaBlock * self) {
 	self->priv = VALA_BLOCK_GET_PRIVATE (self);
 	self->priv->statement_list = GEE_LIST (gee_array_list_new (VALA_TYPE_STATEMENT, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
-	self->priv->local_variables = GEE_LIST (gee_array_list_new (VALA_TYPE_VARIABLE_DECLARATOR, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
+	self->priv->local_variables = GEE_LIST (gee_array_list_new (VALA_TYPE_LOCAL_VARIABLE, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
 }
 
 
