@@ -1,6 +1,6 @@
 /* valablock.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -49,14 +49,16 @@ struct _ValaBlock {
 	ValaSymbol parent_instance;
 	ValaBlockPrivate * priv;
 };
+
 struct _ValaBlockClass {
 	ValaSymbolClass parent_class;
 };
 
+
 ValaBlock* vala_block_new (ValaSourceReference* source_reference);
 void vala_block_add_statement (ValaBlock* self, ValaStatement* stmt);
 GeeCollection* vala_block_get_statements (ValaBlock* self);
-void vala_block_add_local_variable (ValaBlock* self, ValaVariableDeclarator* decl);
+void vala_block_add_local_variable (ValaBlock* self, ValaLocalVariable* local);
 GeeCollection* vala_block_get_local_variables (ValaBlock* self);
 gboolean vala_block_get_contains_jump_statement (ValaBlock* self);
 void vala_block_set_contains_jump_statement (ValaBlock* self, gboolean value);
