@@ -30,6 +30,7 @@
 struct _ValaBooleanLiteralPrivate {
 	gboolean _value;
 };
+
 #define VALA_BOOLEAN_LITERAL_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_BOOLEAN_LITERAL, ValaBooleanLiteralPrivate))
 enum  {
 	VALA_BOOLEAN_LITERAL_DUMMY_PROPERTY,
@@ -52,7 +53,7 @@ static void vala_boolean_literal_dispose (GObject * obj);
  */
 ValaBooleanLiteral* vala_boolean_literal_new (gboolean b, ValaSourceReference* source) {
 	ValaBooleanLiteral * self;
-	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
+	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source), NULL);
 	self = g_object_newv (VALA_TYPE_BOOLEAN_LITERAL, 0, NULL);
 	vala_boolean_literal_set_value (self, b);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
@@ -63,7 +64,7 @@ ValaBooleanLiteral* vala_boolean_literal_new (gboolean b, ValaSourceReference* s
 static void vala_boolean_literal_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaBooleanLiteral * self;
 	self = VALA_BOOLEAN_LITERAL (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_boolean_literal (visitor, self);
 }
 
