@@ -34,15 +34,18 @@ struct _ValaCatchClausePrivate {
 	char* _variable_name;
 	ValaBlock* _body;
 	ValaLocalVariable* _error_variable;
+	char* _clabel_name;
 	ValaDataType* _data_type;
 };
+
 #define VALA_CATCH_CLAUSE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CATCH_CLAUSE, ValaCatchClausePrivate))
 enum  {
 	VALA_CATCH_CLAUSE_DUMMY_PROPERTY,
 	VALA_CATCH_CLAUSE_ERROR_TYPE,
 	VALA_CATCH_CLAUSE_VARIABLE_NAME,
 	VALA_CATCH_CLAUSE_BODY,
-	VALA_CATCH_CLAUSE_ERROR_VARIABLE
+	VALA_CATCH_CLAUSE_ERROR_VARIABLE,
+	VALA_CATCH_CLAUSE_CLABEL_NAME
 };
 static void vala_catch_clause_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static void vala_catch_clause_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
@@ -64,7 +67,6 @@ static void vala_catch_clause_dispose (GObject * obj);
 ValaCatchClause* vala_catch_clause_new (ValaDataType* error_type, const char* variable_name, ValaBlock* body, ValaSourceReference* source_reference) {
 	ValaCatchClause * self;
 	g_return_val_if_fail (error_type == NULL || VALA_IS_DATA_TYPE (error_type), NULL);
-	g_return_val_if_fail (variable_name != NULL, NULL);
 	g_return_val_if_fail (VALA_IS_BLOCK (body), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_CATCH_CLAUSE, 0, NULL);
@@ -173,6 +175,22 @@ void vala_catch_clause_set_error_variable (ValaCatchClause* self, ValaLocalVaria
 }
 
 
+char* vala_catch_clause_get_clabel_name (ValaCatchClause* self) {
+	g_return_val_if_fail (VALA_IS_CATCH_CLAUSE (self), NULL);
+	return self->priv->_clabel_name;
+}
+
+
+void vala_catch_clause_set_clabel_name (ValaCatchClause* self, const char* value) {
+	char* _tmp2;
+	const char* _tmp1;
+	g_return_if_fail (VALA_IS_CATCH_CLAUSE (self));
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_clabel_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_strdup (_tmp1))), (self->priv->_clabel_name = (g_free (self->priv->_clabel_name), NULL)), _tmp2);
+}
+
+
 static void vala_catch_clause_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaCatchClause * self;
 	self = VALA_CATCH_CLAUSE (object);
@@ -189,6 +207,9 @@ static void vala_catch_clause_get_property (GObject * object, guint property_id,
 		case VALA_CATCH_CLAUSE_ERROR_VARIABLE:
 		g_value_set_object (value, vala_catch_clause_get_error_variable (self));
 		break;
+		case VALA_CATCH_CLAUSE_CLABEL_NAME:
+		g_value_set_string (value, vala_catch_clause_get_clabel_name (self));
+		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 		break;
@@ -212,6 +233,9 @@ static void vala_catch_clause_set_property (GObject * object, guint property_id,
 		case VALA_CATCH_CLAUSE_ERROR_VARIABLE:
 		vala_catch_clause_set_error_variable (self, g_value_get_object (value));
 		break;
+		case VALA_CATCH_CLAUSE_CLABEL_NAME:
+		vala_catch_clause_set_clabel_name (self, g_value_get_string (value));
+		break;
 		default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
 		break;
@@ -232,6 +256,7 @@ static void vala_catch_clause_class_init (ValaCatchClauseClass * klass) {
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CATCH_CLAUSE_VARIABLE_NAME, g_param_spec_string ("variable-name", "variable-name", "variable-name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CATCH_CLAUSE_BODY, g_param_spec_object ("body", "body", "body", VALA_TYPE_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CATCH_CLAUSE_ERROR_VARIABLE, g_param_spec_object ("error-variable", "error-variable", "error-variable", VALA_TYPE_LOCAL_VARIABLE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CATCH_CLAUSE_CLABEL_NAME, g_param_spec_string ("clabel-name", "clabel-name", "clabel-name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
@@ -246,6 +271,7 @@ static void vala_catch_clause_dispose (GObject * obj) {
 	self->priv->_variable_name = (g_free (self->priv->_variable_name), NULL);
 	(self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL)));
 	(self->priv->_error_variable == NULL ? NULL : (self->priv->_error_variable = (g_object_unref (self->priv->_error_variable), NULL)));
+	self->priv->_clabel_name = (g_free (self->priv->_clabel_name), NULL);
 	(self->priv->_data_type == NULL ? NULL : (self->priv->_data_type = (g_object_unref (self->priv->_data_type), NULL)));
 	G_OBJECT_CLASS (vala_catch_clause_parent_class)->dispose (obj);
 }
