@@ -30,6 +30,7 @@
 #include <gee/collection.h>
 #include <vala/valatypesymbol.h>
 #include <vala/valacodenode.h>
+#include <vala/valacodebinding.h>
 
 G_BEGIN_DECLS
 
@@ -50,10 +51,12 @@ struct _ValaClass {
 	ValaTypesymbol parent_instance;
 	ValaClassPrivate * priv;
 };
+
 struct _ValaClassClass {
 	ValaTypesymbolClass parent_class;
 };
 
+
 ValaClass* vala_class_new (const char* name, ValaSourceReference* source_reference);
 void vala_class_add_base_type (ValaClass* self, ValaDataType* type);
 GeeCollection* vala_class_get_base_types (ValaClass* self);
@@ -70,6 +73,8 @@ void vala_class_add_signal (ValaClass* self, ValaSignal* sig);
 GeeCollection* vala_class_get_signals (ValaClass* self);
 void vala_class_add_class (ValaClass* self, ValaClass* cl);
 void vala_class_add_struct (ValaClass* self, ValaStruct* st);
+void vala_class_add_enum (ValaClass* self, ValaEnum* en);
+void vala_class_add_delegate (ValaClass* self, ValaDelegate* d);
 char* vala_class_get_default_cname (ValaClass* self);
 void vala_class_set_cname (ValaClass* self, const char* cname);
 void vala_class_process_attributes (ValaClass* self);
@@ -90,10 +95,17 @@ ValaMethod* vala_class_get_default_construction_method (ValaClass* self);
 void vala_class_set_default_construction_method (ValaClass* self, ValaMethod* value);
 ValaConstructor* vala_class_get_constructor (ValaClass* self);
 void vala_class_set_constructor (ValaClass* self, ValaConstructor* value);
+ValaConstructor* vala_class_get_class_constructor (ValaClass* self);
+void vala_class_set_class_constructor (ValaClass* self, ValaConstructor* value);
+ValaConstructor* vala_class_get_static_constructor (ValaClass* self);
+void vala_class_set_static_constructor (ValaClass* self, ValaConstructor* value);
 ValaDestructor* vala_class_get_destructor (ValaClass* self);
 void vala_class_set_destructor (ValaClass* self, ValaDestructor* value);
+gboolean vala_class_get_is_error_base (ValaClass* self);
+void vala_class_set_is_error_base (ValaClass* self, gboolean value);
 GType vala_class_get_type (void);
 
+
 G_END_DECLS
 
 #endif
