@@ -1,6 +1,6 @@
 /* valacodebinding.vala
  *
- * Copyright (C) 2007  Jürg Billeter
+ * Copyright (C) 2007-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -47,12 +47,13 @@ struct _ValaCodeBinding {
 	GObject parent_instance;
 	ValaCodeBindingPrivate * priv;
 };
+
 struct _ValaCodeBindingClass {
 	GObjectClass parent_class;
-	void (*emit) (ValaCodeBinding* self);
 };
 
-void vala_code_binding_emit (ValaCodeBinding* self);
+
+ValaCodeBinding* vala_code_binding_new (void);
 GType vala_code_binding_get_type (void);
 
 
