@@ -44,42 +44,44 @@ typedef struct _ValaSourceFile ValaSourceFile;
 typedef struct _ValaSourceFileClass ValaSourceFileClass;
 typedef struct _ValaCodeContext ValaCodeContext;
 typedef struct _ValaCodeContextClass ValaCodeContextClass;
-typedef struct _ValaNamespace ValaNamespace;
-typedef struct _ValaNamespaceClass ValaNamespaceClass;
 typedef struct _ValaSymbol ValaSymbol;
 typedef struct _ValaSymbolClass ValaSymbolClass;
 typedef struct _ValaScope ValaScope;
 typedef struct _ValaScopeClass ValaScopeClass;
-typedef struct _ValaSourceReference ValaSourceReference;
-typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
-typedef struct _ValaClass ValaClass;
-typedef struct _ValaClassClass ValaClassClass;
+typedef struct _ValaMethod ValaMethod;
+typedef struct _ValaMethodClass ValaMethodClass;
+typedef struct _ValaMember ValaMember;
+typedef struct _ValaMemberClass ValaMemberClass;
 typedef struct _ValaDataType ValaDataType;
 typedef struct _ValaDataTypeClass ValaDataTypeClass;
 typedef struct _ValaTypeParameter ValaTypeParameter;
 typedef struct _ValaTypeParameterClass ValaTypeParameterClass;
-typedef struct _ValaConstant ValaConstant;
-typedef struct _ValaConstantClass ValaConstantClass;
-typedef struct _ValaMember ValaMember;
-typedef struct _ValaMemberClass ValaMemberClass;
-typedef struct _ValaField ValaField;
-typedef struct _ValaFieldClass ValaFieldClass;
-typedef struct _ValaMethod ValaMethod;
-typedef struct _ValaMethodClass ValaMethodClass;
+typedef struct _ValaSourceReference ValaSourceReference;
+typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
 typedef struct _ValaFormalParameter ValaFormalParameter;
 typedef struct _ValaFormalParameterClass ValaFormalParameterClass;
-typedef struct _ValaBlock ValaBlock;
-typedef struct _ValaBlockClass ValaBlockClass;
-typedef struct _ValaStatement ValaStatement;
-typedef struct _ValaStatementIface ValaStatementIface;
-typedef struct _ValaVariableDeclarator ValaVariableDeclarator;
-typedef struct _ValaVariableDeclaratorClass ValaVariableDeclaratorClass;
-typedef struct _ValaBasicBlock ValaBasicBlock;
-typedef struct _ValaBasicBlockClass ValaBasicBlockClass;
+typedef struct _ValaCodeGenerator ValaCodeGenerator;
+typedef struct _ValaCodeGeneratorClass ValaCodeGeneratorClass;
+typedef struct _ValaNamespace ValaNamespace;
+typedef struct _ValaNamespaceClass ValaNamespaceClass;
+typedef struct _ValaClass ValaClass;
+typedef struct _ValaClassClass ValaClassClass;
+typedef struct _ValaConstant ValaConstant;
+typedef struct _ValaConstantClass ValaConstantClass;
+typedef struct _ValaField ValaField;
+typedef struct _ValaFieldClass ValaFieldClass;
 typedef struct _ValaProperty ValaProperty;
 typedef struct _ValaPropertyClass ValaPropertyClass;
 typedef struct _ValaPropertyAccessor ValaPropertyAccessor;
 typedef struct _ValaPropertyAccessorClass ValaPropertyAccessorClass;
+typedef struct _ValaBlock ValaBlock;
+typedef struct _ValaBlockClass ValaBlockClass;
+typedef struct _ValaStatement ValaStatement;
+typedef struct _ValaStatementIface ValaStatementIface;
+typedef struct _ValaLocalVariable ValaLocalVariable;
+typedef struct _ValaLocalVariableClass ValaLocalVariableClass;
+typedef struct _ValaBasicBlock ValaBasicBlock;
+typedef struct _ValaBasicBlockClass ValaBasicBlockClass;
 typedef struct _ValaSignal ValaSignal;
 typedef struct _ValaSignalClass ValaSignalClass;
 typedef struct _ValaDelegate ValaDelegate;
@@ -100,14 +102,18 @@ typedef struct _ValaErrorDomain ValaErrorDomain;
 typedef struct _ValaErrorDomainClass ValaErrorDomainClass;
 typedef struct _ValaErrorCode ValaErrorCode;
 typedef struct _ValaErrorCodeClass ValaErrorCodeClass;
+typedef struct _ValaDynamicMethod ValaDynamicMethod;
+typedef struct _ValaDynamicMethodClass ValaDynamicMethodClass;
+typedef struct _ValaInvocationExpression ValaInvocationExpression;
+typedef struct _ValaInvocationExpressionClass ValaInvocationExpressionClass;
 typedef struct _ValaCreationMethod ValaCreationMethod;
 typedef struct _ValaCreationMethodClass ValaCreationMethodClass;
+typedef struct _ValaDynamicSignal ValaDynamicSignal;
+typedef struct _ValaDynamicSignalClass ValaDynamicSignalClass;
 typedef struct _ValaEmptyStatement ValaEmptyStatement;
 typedef struct _ValaEmptyStatementClass ValaEmptyStatementClass;
 typedef struct _ValaDeclarationStatement ValaDeclarationStatement;
 typedef struct _ValaDeclarationStatementClass ValaDeclarationStatementClass;
-typedef struct _ValaLocalVariableDeclaration ValaLocalVariableDeclaration;
-typedef struct _ValaLocalVariableDeclarationClass ValaLocalVariableDeclarationClass;
 typedef struct _ValaInitializerList ValaInitializerList;
 typedef struct _ValaInitializerListClass ValaInitializerListClass;
 typedef struct _ValaExpressionStatement ValaExpressionStatement;
@@ -164,8 +170,6 @@ typedef struct _ValaParenthesizedExpression ValaParenthesizedExpression;
 typedef struct _ValaParenthesizedExpressionClass ValaParenthesizedExpressionClass;
 typedef struct _ValaMemberAccess ValaMemberAccess;
 typedef struct _ValaMemberAccessClass ValaMemberAccessClass;
-typedef struct _ValaInvocationExpression ValaInvocationExpression;
-typedef struct _ValaInvocationExpressionClass ValaInvocationExpressionClass;
 typedef struct _ValaElementAccess ValaElementAccess;
 typedef struct _ValaElementAccessClass ValaElementAccessClass;
 typedef struct _ValaBaseAccess ValaBaseAccess;
@@ -198,8 +202,6 @@ typedef struct _ValaLambdaExpression ValaLambdaExpression;
 typedef struct _ValaLambdaExpressionClass ValaLambdaExpressionClass;
 typedef struct _ValaAssignment ValaAssignment;
 typedef struct _ValaAssignmentClass ValaAssignmentClass;
-typedef struct _ValaCodeGenerator ValaCodeGenerator;
-typedef struct _ValaCodeGeneratorClass ValaCodeGeneratorClass;
 typedef struct _ValaNamespaceReference ValaNamespaceReference;
 typedef struct _ValaNamespaceReferenceClass ValaNamespaceReferenceClass;
 typedef struct _ValaSourceFileCycle ValaSourceFileCycle;
@@ -229,6 +231,7 @@ struct _ValaCodeNode {
 	ValaCodeNodePrivate * priv;
 	GList* attributes;
 };
+
 struct _ValaCodeNodeClass {
 	GObjectClass parent_class;
 	void (*accept) (ValaCodeNode* self, ValaCodeVisitor* visitor);
@@ -236,22 +239,25 @@ struct _ValaCodeNodeClass {
 	void (*replace_type) (ValaCodeNode* self, ValaDataType* old_type, ValaDataType* new_type);
 	void (*replace_expression) (ValaCodeNode* self, ValaExpression* old_node, ValaExpression* new_node);
 	char* (*to_string) (ValaCodeNode* self);
+	ValaCodeBinding* (*create_code_binding) (ValaCodeNode* self, ValaCodeGenerator* codegen);
 };
 
+
 void vala_code_node_accept (ValaCodeNode* self, ValaCodeVisitor* visitor);
 void vala_code_node_accept_children (ValaCodeNode* self, ValaCodeVisitor* visitor);
 void vala_code_node_replace_type (ValaCodeNode* self, ValaDataType* old_type, ValaDataType* new_type);
 void vala_code_node_replace_expression (ValaCodeNode* self, ValaExpression* old_node, ValaExpression* new_node);
 ValaAttribute* vala_code_node_get_attribute (ValaCodeNode* self, const char* name);
 char* vala_code_node_to_string (ValaCodeNode* self);
+ValaCodeBinding* vala_code_node_get_code_binding (ValaCodeNode* self, ValaCodeGenerator* codegen);
+ValaCodeBinding* vala_code_node_create_code_binding (ValaCodeNode* self, ValaCodeGenerator* codegen);
+ValaCodeNode* vala_code_node_new (void);
 ValaCodeNode* vala_code_node_get_parent_node (ValaCodeNode* self);
 void vala_code_node_set_parent_node (ValaCodeNode* self, ValaCodeNode* value);
 ValaSourceReference* vala_code_node_get_source_reference (ValaCodeNode* self);
 void vala_code_node_set_source_reference (ValaCodeNode* self, ValaSourceReference* value);
 ValaCCodeNode* vala_code_node_get_ccodenode (ValaCodeNode* self);
 void vala_code_node_set_ccodenode (ValaCodeNode* self, ValaCCodeNode* value);
-ValaCodeBinding* vala_code_node_get_code_binding (ValaCodeNode* self);
-void vala_code_node_set_code_binding (ValaCodeNode* self, ValaCodeBinding* value);
 gboolean vala_code_node_get_error (ValaCodeNode* self);
 void vala_code_node_set_error (ValaCodeNode* self, gboolean value);
 gboolean vala_code_node_get_tree_can_fail (ValaCodeNode* self);
