@@ -1,6 +1,6 @@
 /* valaconstant.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -37,6 +37,7 @@ struct _ValaConstantPrivate {
 	gboolean lock_used;
 	ValaDataType* _data_type;
 };
+
 #define VALA_CONSTANT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CONSTANT, ValaConstantPrivate))
 enum  {
 	VALA_CONSTANT_DUMMY_PROPERTY,
@@ -68,7 +69,8 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
  */
 ValaConstant* vala_constant_new (const char* name, ValaDataType* type_reference, ValaExpression* initializer, ValaSourceReference* source_reference) {
 	ValaConstant * self;
-	g_return_val_if_fail (type_reference == NULL || VALA_IS_DATA_TYPE (type_reference), NULL);
+	g_return_val_if_fail (name != NULL, NULL);
+	g_return_val_if_fail (VALA_IS_DATA_TYPE (type_reference), NULL);
 	g_return_val_if_fail (initializer == NULL || VALA_IS_EXPRESSION (initializer), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_CONSTANT, 0, NULL);
@@ -83,7 +85,7 @@ ValaConstant* vala_constant_new (const char* name, ValaDataType* type_reference,
 static void vala_constant_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaConstant * self;
 	self = VALA_CONSTANT (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_member (visitor, VALA_MEMBER (self));
 	vala_code_visitor_visit_constant (visitor, self);
 }
@@ -92,7 +94,7 @@ static void vala_constant_real_accept (ValaCodeNode* base, ValaCodeVisitor* visi
 static void vala_constant_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaConstant * self;
 	self = VALA_CONSTANT (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_constant_get_type_reference (self)), visitor);
 	if (self->priv->_initializer != NULL) {
 		vala_code_node_accept (VALA_CODE_NODE (self->priv->_initializer), visitor);
@@ -150,8 +152,8 @@ static void vala_constant_real_set_lock_used (ValaLockable* base, gboolean used)
 static void vala_constant_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type) {
 	ValaConstant * self;
 	self = VALA_CONSTANT (base);
-	g_return_if_fail (old_type == NULL || VALA_IS_DATA_TYPE (old_type));
-	g_return_if_fail (new_type == NULL || VALA_IS_DATA_TYPE (new_type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (old_type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (new_type));
 	if (vala_constant_get_type_reference (self) == old_type) {
 		vala_constant_set_type_reference (self, new_type);
 	}
@@ -160,7 +162,7 @@ static void vala_constant_real_replace_type (ValaCodeNode* base, ValaDataType* o
 
 static void vala_constant_process_ccode_attribute (ValaConstant* self, ValaAttribute* a) {
 	g_return_if_fail (VALA_IS_CONSTANT (self));
-	g_return_if_fail (a == NULL || VALA_IS_ATTRIBUTE (a));
+	g_return_if_fail (VALA_IS_ATTRIBUTE (a));
 	if (vala_attribute_has_argument (a, "cname")) {
 		char* _tmp0;
 		_tmp0 = NULL;
