@@ -33,11 +33,15 @@
 #include <vala/valasymbol.h>
 #include <vala/valascope.h>
 #include <vala/valamethod.h>
+#include <vala/valamember.h>
 #include <vala/valacodevisitor.h>
 #include <vala/valaattribute.h>
 
+
+
+
 struct _ValaDelegatePrivate {
-	gboolean _instance;
+	gboolean _has_target;
 	double _cinstance_parameter_position;
 	double _carray_length_parameter_position;
 	double _cdelegate_target_parameter_position;
@@ -47,11 +51,12 @@ struct _ValaDelegatePrivate {
 	ValaDataType* _return_type;
 	gboolean _no_array_length;
 };
+
 #define VALA_DELEGATE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_DELEGATE, ValaDelegatePrivate))
 enum  {
 	VALA_DELEGATE_DUMMY_PROPERTY,
 	VALA_DELEGATE_RETURN_TYPE,
-	VALA_DELEGATE_INSTANCE,
+	VALA_DELEGATE_HAS_TARGET,
 	VALA_DELEGATE_CINSTANCE_PARAMETER_POSITION,
 	VALA_DELEGATE_CARRAY_LENGTH_PARAMETER_POSITION,
 	VALA_DELEGATE_CDELEGATE_TARGET_PARAMETER_POSITION,
@@ -74,6 +79,7 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
 static int _vala_strcmp0 (const char * str1, const char * str2);
 
 
+
 /**
  * Creates a new delegate.
  *
@@ -84,7 +90,7 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
  */
 ValaDelegate* vala_delegate_new (const char* name, ValaDataType* return_type, ValaSourceReference* source_reference) {
 	ValaDelegate * self;
-	g_return_val_if_fail (return_type == NULL || VALA_IS_DATA_TYPE (return_type), NULL);
+	g_return_val_if_fail (VALA_IS_DATA_TYPE (return_type), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	self = g_object_newv (VALA_TYPE_DELEGATE, 0, NULL);
 	vala_symbol_set_name (VALA_SYMBOL (self), name);
@@ -101,7 +107,7 @@ ValaDelegate* vala_delegate_new (const char* name, ValaDataType* return_type, Va
  */
 void vala_delegate_add_type_parameter (ValaDelegate* self, ValaTypeParameter* p) {
 	g_return_if_fail (VALA_IS_DELEGATE (self));
-	g_return_if_fail (p == NULL || VALA_IS_TYPEPARAMETER (p));
+	g_return_if_fail (VALA_IS_TYPEPARAMETER (p));
 	gee_collection_add (GEE_COLLECTION (self->priv->type_parameters), p);
 	p->type = VALA_TYPESYMBOL (self);
 	vala_scope_add (vala_symbol_get_scope (VALA_SYMBOL (self)), vala_symbol_get_name (VALA_SYMBOL (p)), VALA_SYMBOL (p));
@@ -115,7 +121,7 @@ void vala_delegate_add_type_parameter (ValaDelegate* self, ValaTypeParameter* p)
  */
 void vala_delegate_add_parameter (ValaDelegate* self, ValaFormalParameter* param) {
 	g_return_if_fail (VALA_IS_DELEGATE (self));
-	g_return_if_fail (param == NULL || VALA_IS_FORMAL_PARAMETER (param));
+	g_return_if_fail (VALA_IS_FORMAL_PARAMETER (param));
 	if (vala_delegate_get_no_array_length (self)) {
 		vala_formal_parameter_set_no_array_length (param, TRUE);
 	}
@@ -152,7 +158,8 @@ gboolean vala_delegate_matches_method (ValaDelegate* self, ValaMethod* m) {
 	gboolean first;
 	gboolean _tmp3;
 	g_return_val_if_fail (VALA_IS_DELEGATE (self), FALSE);
-	g_return_val_if_fail (m == NULL || VALA_IS_METHOD (m), FALSE);
+	g_return_val_if_fail (VALA_IS_METHOD (m), FALSE);
+	/* method is allowed to ensure stricter return type (stronger postcondition)*/
 	if (!vala_data_type_stricter (vala_method_get_return_type (m), vala_delegate_get_return_type (self))) {
 		return FALSE;
 	}
@@ -173,7 +180,7 @@ gboolean vala_delegate_matches_method (ValaDelegate* self, ValaMethod* m) {
 				 * an instance method is being compared to a static
 				 * callback
 				 */
-				if (first && vala_method_get_instance (m) && !vala_delegate_get_instance (self)) {
+				if (first && vala_method_get_binding (m) == MEMBER_BINDING_INSTANCE && !self->priv->_has_target) {
 					first = FALSE;
 					(param == NULL ? NULL : (param = (g_object_unref (param), NULL)));
 					continue;
@@ -183,6 +190,7 @@ gboolean vala_delegate_matches_method (ValaDelegate* self, ValaMethod* m) {
 					(param == NULL ? NULL : (param = (g_object_unref (param), NULL)));
 					break;
 				}
+				/* method is allowed to accept arguments of looser types (weaker precondition)*/
 				method_param = ((ValaFormalParameter*) gee_iterator_get (method_params_it));
 				if (!vala_data_type_stricter (vala_formal_parameter_get_type_reference (param), vala_formal_parameter_get_type_reference (method_param))) {
 					gboolean _tmp1;
@@ -206,7 +214,7 @@ gboolean vala_delegate_matches_method (ValaDelegate* self, ValaMethod* m) {
 static void vala_delegate_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaDelegate * self;
 	self = VALA_DELEGATE (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_delegate (visitor, self);
 }
 
@@ -214,7 +222,7 @@ static void vala_delegate_real_accept (ValaCodeNode* base, ValaCodeVisitor* visi
 static void vala_delegate_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaDelegate * self;
 	self = VALA_DELEGATE (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	{
 		GeeList* p_collection;
 		GeeIterator* p_it;
@@ -275,6 +283,7 @@ void vala_delegate_set_cname (ValaDelegate* self, const char* cname) {
 	char* _tmp1;
 	const char* _tmp0;
 	g_return_if_fail (VALA_IS_DELEGATE (self));
+	g_return_if_fail (cname != NULL);
 	_tmp1 = NULL;
 	_tmp0 = NULL;
 	self->priv->cname = (_tmp1 = (_tmp0 = cname, (_tmp0 == NULL ? NULL : g_strdup (_tmp0))), (self->priv->cname = (g_free (self->priv->cname), NULL)), _tmp1);
@@ -283,7 +292,7 @@ void vala_delegate_set_cname (ValaDelegate* self, const char* cname) {
 
 static void vala_delegate_process_ccode_attribute (ValaDelegate* self, ValaAttribute* a) {
 	g_return_if_fail (VALA_IS_DELEGATE (self));
-	g_return_if_fail (a == NULL || VALA_IS_ATTRIBUTE (a));
+	g_return_if_fail (VALA_IS_ATTRIBUTE (a));
 	if (vala_attribute_has_argument (a, "cname")) {
 		char* _tmp0;
 		_tmp0 = NULL;
@@ -392,8 +401,8 @@ static char* vala_delegate_real_get_set_value_function (ValaTypesymbol* base) {
 static void vala_delegate_real_replace_type (ValaCodeNode* base, ValaDataType* old_type, ValaDataType* new_type) {
 	ValaDelegate * self;
 	self = VALA_DELEGATE (base);
-	g_return_if_fail (old_type == NULL || VALA_IS_DATA_TYPE (old_type));
-	g_return_if_fail (new_type == NULL || VALA_IS_DATA_TYPE (new_type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (old_type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (new_type));
 	if (vala_delegate_get_return_type (self) == old_type) {
 		vala_delegate_set_return_type (self, new_type);
 	}
@@ -417,15 +426,15 @@ void vala_delegate_set_return_type (ValaDelegate* self, ValaDataType* value) {
 }
 
 
-gboolean vala_delegate_get_instance (ValaDelegate* self) {
+gboolean vala_delegate_get_has_target (ValaDelegate* self) {
 	g_return_val_if_fail (VALA_IS_DELEGATE (self), FALSE);
-	return self->priv->_instance;
+	return self->priv->_has_target;
 }
 
 
-void vala_delegate_set_instance (ValaDelegate* self, gboolean value) {
+void vala_delegate_set_has_target (ValaDelegate* self, gboolean value) {
 	g_return_if_fail (VALA_IS_DELEGATE (self));
-	self->priv->_instance = value;
+	self->priv->_has_target = value;
 }
 
 
@@ -517,8 +526,8 @@ static void vala_delegate_get_property (GObject * object, guint property_id, GVa
 		case VALA_DELEGATE_RETURN_TYPE:
 		g_value_set_object (value, vala_delegate_get_return_type (self));
 		break;
-		case VALA_DELEGATE_INSTANCE:
-		g_value_set_boolean (value, vala_delegate_get_instance (self));
+		case VALA_DELEGATE_HAS_TARGET:
+		g_value_set_boolean (value, vala_delegate_get_has_target (self));
 		break;
 		case VALA_DELEGATE_CINSTANCE_PARAMETER_POSITION:
 		g_value_set_double (value, vala_delegate_get_cinstance_parameter_position (self));
@@ -546,8 +555,8 @@ static void vala_delegate_set_property (GObject * object, guint property_id, con
 		case VALA_DELEGATE_RETURN_TYPE:
 		vala_delegate_set_return_type (self, g_value_get_object (value));
 		break;
-		case VALA_DELEGATE_INSTANCE:
-		vala_delegate_set_instance (self, g_value_get_boolean (value));
+		case VALA_DELEGATE_HAS_TARGET:
+		vala_delegate_set_has_target (self, g_value_get_boolean (value));
 		break;
 		case VALA_DELEGATE_CINSTANCE_PARAMETER_POSITION:
 		vala_delegate_set_cinstance_parameter_position (self, g_value_get_double (value));
@@ -585,7 +594,7 @@ static void vala_delegate_class_init (ValaDelegateClass * klass) {
 	VALA_TYPESYMBOL_CLASS (klass)->get_set_value_function = vala_delegate_real_get_set_value_function;
 	VALA_CODE_NODE_CLASS (klass)->replace_type = vala_delegate_real_replace_type;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DELEGATE_RETURN_TYPE, g_param_spec_object ("return-type", "return-type", "return-type", VALA_TYPE_DATA_TYPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DELEGATE_INSTANCE, g_param_spec_boolean ("instance", "instance", "instance", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DELEGATE_HAS_TARGET, g_param_spec_boolean ("has-target", "has-target", "has-target", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DELEGATE_CINSTANCE_PARAMETER_POSITION, g_param_spec_double ("cinstance-parameter-position", "cinstance-parameter-position", "cinstance-parameter-position", -G_MAXDOUBLE, G_MAXDOUBLE, 0.0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DELEGATE_CARRAY_LENGTH_PARAMETER_POSITION, g_param_spec_double ("carray-length-parameter-position", "carray-length-parameter-position", "carray-length-parameter-position", -G_MAXDOUBLE, G_MAXDOUBLE, 0.0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DELEGATE_CDELEGATE_TARGET_PARAMETER_POSITION, g_param_spec_double ("cdelegate-target-parameter-position", "cdelegate-target-parameter-position", "cdelegate-target-parameter-position", -G_MAXDOUBLE, G_MAXDOUBLE, 0.0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
