@@ -34,6 +34,7 @@
 struct _ValaExpressionStatementPrivate {
 	ValaExpression* _expression;
 };
+
 #define VALA_EXPRESSION_STATEMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_EXPRESSION_STATEMENT, ValaExpressionStatementPrivate))
 enum  {
 	VALA_EXPRESSION_STATEMENT_DUMMY_PROPERTY,
@@ -58,7 +59,7 @@ ValaExpressionStatement* vala_expression_statement_new (ValaExpression* expressi
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaExpressionStatement * self;
-	g_return_val_if_fail (expression == NULL || VALA_IS_EXPRESSION (expression), NULL);
+	g_return_val_if_fail (VALA_IS_EXPRESSION (expression), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
@@ -80,7 +81,7 @@ ValaExpressionStatement* vala_expression_statement_new (ValaExpression* expressi
 static void vala_expression_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaExpressionStatement * self;
 	self = VALA_EXPRESSION_STATEMENT (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_expression_statement_get_expression (self)), visitor);
 	vala_code_visitor_visit_expression_statement (visitor, self);
 }
@@ -89,8 +90,8 @@ static void vala_expression_statement_real_accept (ValaCodeNode* base, ValaCodeV
 static void vala_expression_statement_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node) {
 	ValaExpressionStatement * self;
 	self = VALA_EXPRESSION_STATEMENT (base);
-	g_return_if_fail (old_node == NULL || VALA_IS_EXPRESSION (old_node));
-	g_return_if_fail (new_node == NULL || VALA_IS_EXPRESSION (new_node));
+	g_return_if_fail (VALA_IS_EXPRESSION (old_node));
+	g_return_if_fail (VALA_IS_EXPRESSION (new_node));
 	if (vala_expression_statement_get_expression (self) == old_node) {
 		vala_expression_statement_set_expression (self, new_node);
 	}
