@@ -32,6 +32,7 @@ struct _ValaInstanceCastPrivate {
 	ValaTypesymbol* _type_reference;
 	ValaCCodeExpression* _inner;
 };
+
 #define VALA_INSTANCE_CAST_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_INSTANCE_CAST, ValaInstanceCastPrivate))
 enum  {
 	VALA_INSTANCE_CAST_DUMMY_PROPERTY,
@@ -55,8 +56,8 @@ ValaInstanceCast* vala_instance_cast_new (ValaCCodeExpression* expr, ValaTypesym
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaInstanceCast * self;
-	g_return_val_if_fail (expr == NULL || VALA_IS_CCODE_EXPRESSION (expr), NULL);
-	g_return_val_if_fail (type == NULL || VALA_IS_TYPESYMBOL (type), NULL);
+	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (expr), NULL);
+	g_return_val_if_fail (VALA_IS_TYPESYMBOL (type), NULL);
 	__params = g_new0 (GParameter, 2);
 	__params_it = __params;
 	__params_it->name = "inner";
