@@ -34,13 +34,14 @@
 struct _ValaIntegerTypePrivate {
 	ValaIntegerLiteral* _literal;
 };
+
 #define VALA_INTEGER_TYPE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_INTEGER_TYPE, ValaIntegerTypePrivate))
 enum  {
 	VALA_INTEGER_TYPE_DUMMY_PROPERTY,
 	VALA_INTEGER_TYPE_LITERAL
 };
 static ValaDataType* vala_integer_type_real_copy (ValaDataType* base);
-static gboolean vala_integer_type_real_compatible (ValaDataType* base, ValaDataType* target_type, gboolean enable_non_null);
+static gboolean vala_integer_type_real_compatible (ValaDataType* base, ValaDataType* target_type);
 static gpointer vala_integer_type_parent_class = NULL;
 static void vala_integer_type_dispose (GObject * obj);
 static int _vala_strcmp0 (const char * str1, const char * str2);
@@ -49,10 +50,10 @@ static int _vala_strcmp0 (const char * str1, const char * str2);
 
 ValaIntegerType* vala_integer_type_new (ValaTypesymbol* type_symbol) {
 	ValaIntegerType * self;
-	g_return_val_if_fail (type_symbol == NULL || VALA_IS_TYPESYMBOL (type_symbol), NULL);
+	g_return_val_if_fail (VALA_IS_TYPESYMBOL (type_symbol), NULL);
 	self = g_object_newv (VALA_TYPE_INTEGER_TYPE, 0, NULL);
-	vala_data_type_set_data_type (VALA_DATA_TYPE (self), type_symbol);
 	vala_value_type_set_type_symbol (VALA_VALUE_TYPE (self), type_symbol);
+	vala_data_type_set_data_type (VALA_DATA_TYPE (self), type_symbol);
 	return self;
 }
 
@@ -67,12 +68,12 @@ static ValaDataType* vala_integer_type_real_copy (ValaDataType* base) {
 }
 
 
-static gboolean vala_integer_type_real_compatible (ValaDataType* base, ValaDataType* target_type, gboolean enable_non_null) {
+static gboolean vala_integer_type_real_compatible (ValaDataType* base, ValaDataType* target_type) {
 	ValaIntegerType * self;
 	char* _tmp0;
 	gboolean _tmp1;
 	self = VALA_INTEGER_TYPE (base);
-	g_return_val_if_fail (target_type == NULL || VALA_IS_DATA_TYPE (target_type), FALSE);
+	g_return_val_if_fail (VALA_IS_DATA_TYPE (target_type), FALSE);
 	_tmp0 = NULL;
 	if ((_tmp1 = VALA_IS_STRUCT (vala_data_type_get_data_type (target_type)) && _vala_strcmp0 ((_tmp0 = vala_integer_literal_get_type_name (self->priv->_literal)), "int") == 0, (_tmp0 = (g_free (_tmp0), NULL)), _tmp1)) {
 		ValaStruct* _tmp2;
@@ -85,27 +86,31 @@ static gboolean vala_integer_type_real_compatible (ValaDataType* base, ValaDataT
 		if (vala_struct_is_integer_type (target_st)) {
 			ValaAttribute* int_attr;
 			int_attr = vala_code_node_get_attribute (VALA_CODE_NODE (target_st), "IntegerType");
-			if (vala_attribute_has_argument (int_attr, "min") && vala_attribute_has_argument (int_attr, "max")) {
+			if (int_attr != NULL && vala_attribute_has_argument (int_attr, "min") && vala_attribute_has_argument (int_attr, "max")) {
 				gint val;
 				gboolean _tmp3;
 				val = atoi (vala_integer_literal_get_value (self->priv->_literal));
 				return (_tmp3 = (val >= vala_attribute_get_integer (int_attr, "min") && val <= vala_attribute_get_integer (int_attr, "max")), (int_attr == NULL ? NULL : (int_attr = (g_object_unref (int_attr), NULL))), (target_st == NULL ? NULL : (target_st = (g_object_unref (target_st), NULL))), _tmp3);
+			} else {
+				gboolean _tmp4;
+				/* assume to be compatible if the target type doesn't specify limits*/
+				return (_tmp4 = TRUE, (int_attr == NULL ? NULL : (int_attr = (g_object_unref (int_attr), NULL))), (target_st == NULL ? NULL : (target_st = (g_object_unref (target_st), NULL))), _tmp4);
 			}
 			(int_attr == NULL ? NULL : (int_attr = (g_object_unref (int_attr), NULL)));
 		}
 		(target_st == NULL ? NULL : (target_st = (g_object_unref (target_st), NULL)));
 	} else {
-		char* _tmp4;
-		gboolean _tmp5;
-		_tmp4 = NULL;
-		if ((_tmp5 = VALA_IS_ENUM (vala_data_type_get_data_type (target_type)) && _vala_strcmp0 ((_tmp4 = vala_integer_literal_get_type_name (self->priv->_literal)), "int") == 0, (_tmp4 = (g_free (_tmp4), NULL)), _tmp5)) {
+		char* _tmp5;
+		gboolean _tmp6;
+		_tmp5 = NULL;
+		if ((_tmp6 = VALA_IS_ENUM (vala_data_type_get_data_type (target_type)) && _vala_strcmp0 ((_tmp5 = vala_integer_literal_get_type_name (self->priv->_literal)), "int") == 0, (_tmp5 = (g_free (_tmp5), NULL)), _tmp6)) {
 			/* allow implicit conversion from 0 to enum and flags types*/
 			if (atoi (vala_integer_literal_get_value (self->priv->_literal)) == 0) {
 				return TRUE;
 			}
 		}
 	}
-	return VALA_DATA_TYPE_CLASS (vala_integer_type_parent_class)->compatible (VALA_DATA_TYPE (VALA_VALUE_TYPE (self)), target_type, enable_non_null);
+	return VALA_DATA_TYPE_CLASS (vala_integer_type_parent_class)->compatible (VALA_DATA_TYPE (VALA_VALUE_TYPE (self)), target_type);
 }
 
 
