@@ -29,12 +29,14 @@
 struct _ValaInterfaceTypePrivate {
 	ValaInterface* _interface_symbol;
 };
+
 #define VALA_INTERFACE_TYPE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_INTERFACE_TYPE, ValaInterfaceTypePrivate))
 enum  {
 	VALA_INTERFACE_TYPE_DUMMY_PROPERTY,
 	VALA_INTERFACE_TYPE_INTERFACE_SYMBOL
 };
 static ValaDataType* vala_interface_type_real_copy (ValaDataType* base);
+static char* vala_interface_type_real_get_cname (ValaDataType* base);
 static gpointer vala_interface_type_parent_class = NULL;
 static void vala_interface_type_dispose (GObject * obj);
 
@@ -42,9 +44,8 @@ static void vala_interface_type_dispose (GObject * obj);
 
 ValaInterfaceType* vala_interface_type_new (ValaInterface* interface_symbol) {
 	ValaInterfaceType * self;
-	g_return_val_if_fail (interface_symbol == NULL || VALA_IS_INTERFACE (interface_symbol), NULL);
+	g_return_val_if_fail (VALA_IS_INTERFACE (interface_symbol), NULL);
 	self = g_object_newv (VALA_TYPE_INTERFACE_TYPE, 0, NULL);
-	vala_data_type_set_data_type (VALA_DATA_TYPE (self), VALA_TYPESYMBOL (interface_symbol));
 	vala_interface_type_set_interface_symbol (self, interface_symbol);
 	return self;
 }
@@ -58,11 +59,9 @@ static ValaDataType* vala_interface_type_real_copy (ValaDataType* base) {
 	vala_code_node_set_source_reference (VALA_CODE_NODE (result), vala_code_node_get_source_reference (VALA_CODE_NODE (self)));
 	vala_data_type_set_transfers_ownership (VALA_DATA_TYPE (result), vala_data_type_get_transfers_ownership (VALA_DATA_TYPE (self)));
 	vala_data_type_set_takes_ownership (VALA_DATA_TYPE (result), vala_data_type_get_takes_ownership (VALA_DATA_TYPE (self)));
-	vala_data_type_set_is_out (VALA_DATA_TYPE (result), vala_data_type_get_is_out (VALA_DATA_TYPE (self)));
 	vala_data_type_set_nullable (VALA_DATA_TYPE (result), vala_data_type_get_nullable (VALA_DATA_TYPE (self)));
-	vala_data_type_set_requires_null_check (VALA_DATA_TYPE (result), vala_data_type_get_requires_null_check (VALA_DATA_TYPE (self)));
+	vala_data_type_set_is_dynamic (VALA_DATA_TYPE (result), vala_data_type_get_is_dynamic (VALA_DATA_TYPE (self)));
 	vala_data_type_set_floating_reference (VALA_DATA_TYPE (result), vala_data_type_get_floating_reference (VALA_DATA_TYPE (self)));
-	vala_data_type_set_is_ref (VALA_DATA_TYPE (result), vala_data_type_get_is_ref (VALA_DATA_TYPE (self)));
 	{
 		GeeList* arg_collection;
 		GeeIterator* arg_it;
@@ -86,6 +85,17 @@ static ValaDataType* vala_interface_type_real_copy (ValaDataType* base) {
 }
 
 
+static char* vala_interface_type_real_get_cname (ValaDataType* base) {
+	ValaInterfaceType * self;
+	char* _tmp0;
+	char* _tmp1;
+	self = VALA_INTERFACE_TYPE (base);
+	_tmp0 = NULL;
+	_tmp1 = NULL;
+	return (_tmp1 = g_strdup_printf ("%sIface*", (_tmp0 = vala_typesymbol_get_cname (VALA_TYPESYMBOL (self->priv->_interface_symbol), FALSE))), (_tmp0 = (g_free (_tmp0), NULL)), _tmp1);
+}
+
+
 ValaInterface* vala_interface_type_get_interface_symbol (ValaInterfaceType* self) {
 	g_return_val_if_fail (VALA_IS_INTERFACE_TYPE (self), NULL);
 	return self->priv->_interface_symbol;
@@ -133,6 +143,7 @@ static void vala_interface_type_class_init (ValaInterfaceTypeClass * klass) {
 	G_OBJECT_CLASS (klass)->set_property = vala_interface_type_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_interface_type_dispose;
 	VALA_DATA_TYPE_CLASS (klass)->copy = vala_interface_type_real_copy;
+	VALA_DATA_TYPE_CLASS (klass)->get_cname = vala_interface_type_real_get_cname;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_INTERFACE_TYPE_INTERFACE_SYMBOL, g_param_spec_object ("interface-symbol", "interface-symbol", "interface-symbol", VALA_TYPE_INTERFACE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
