@@ -27,15 +27,13 @@
 #include <float.h>
 #include <math.h>
 #include <vala/valasymbol.h>
-#include <vala/valacodenode.h>
-#include <vala/valasourcereference.h>
-#include <vala/valasourcefile.h>
 #include <vala/valatypesymbol.h>
 #include <vala/valatypeparameter.h>
 #include <vala/valadatatype.h>
 #include <vala/valaenumvalue.h>
 #include <vala/valaarraytype.h>
 #include <vala/valaformalparameter.h>
+#include <vala/valacodenode.h>
 #include <vala/valamember.h>
 #include <vala/valapropertyaccessor.h>
 
@@ -49,6 +47,7 @@ struct _ValaInterfaceWriterPrivate {
 	gboolean bol;
 	char* current_cheader_filename;
 };
+
 #define VALA_INTERFACE_WRITER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_INTERFACE_WRITER, ValaInterfaceWriterPrivate))
 enum  {
 	VALA_INTERFACE_WRITER_DUMMY_PROPERTY
@@ -101,7 +100,8 @@ void vala_interface_writer_write_file (ValaInterfaceWriter* self, ValaCodeContex
 	char* _tmp3;
 	FILE* _tmp5;
 	g_return_if_fail (VALA_IS_INTERFACE_WRITER (self));
-	g_return_if_fail (context == NULL || VALA_IS_CODE_CONTEXT (context));
+	g_return_if_fail (VALA_IS_CODE_CONTEXT (context));
+	g_return_if_fail (filename != NULL);
 	_tmp1 = NULL;
 	_tmp0 = NULL;
 	self->priv->context = (_tmp1 = (_tmp0 = context, (_tmp0 == NULL ? NULL : g_object_ref (_tmp0))), (self->priv->context == NULL ? NULL : (self->priv->context = (g_object_unref (self->priv->context), NULL))), _tmp1);
@@ -126,8 +126,8 @@ static void vala_interface_writer_real_visit_namespace (ValaCodeVisitor* base, V
 	char* _tmp1;
 	char* _tmp0;
 	self = VALA_INTERFACE_WRITER (base);
-	g_return_if_fail (ns == NULL || VALA_IS_NAMESPACE (ns));
-	if (vala_namespace_get_pkg (ns)) {
+	g_return_if_fail (VALA_IS_NAMESPACE (ns));
+	if (vala_symbol_get_external_package (VALA_SYMBOL (ns))) {
 		return;
 	}
 	if (vala_symbol_get_name (VALA_SYMBOL (ns)) == NULL) {
@@ -164,8 +164,8 @@ static void vala_interface_writer_real_visit_class (ValaCodeVisitor* base, ValaC
 	GeeCollection* type_params;
 	GeeCollection* base_types;
 	self = VALA_INTERFACE_WRITER (base);
-	g_return_if_fail (cl == NULL || VALA_IS_CLASS (cl));
-	if (vala_code_node_get_source_reference (VALA_CODE_NODE (cl)) != NULL && vala_source_file_get_pkg (vala_source_reference_get_file (vala_code_node_get_source_reference (VALA_CODE_NODE (cl))))) {
+	g_return_if_fail (VALA_IS_CLASS (cl));
+	if (vala_symbol_get_external_package (VALA_SYMBOL (cl))) {
 		return;
 	}
 	if (!vala_interface_writer_check_accessibility (self, VALA_SYMBOL (cl))) {
@@ -354,18 +354,34 @@ static void vala_interface_writer_real_visit_class (ValaCodeVisitor* base, ValaC
 
 static void vala_interface_writer_real_visit_struct (ValaCodeVisitor* base, ValaStruct* st) {
 	ValaInterfaceWriter * self;
+	char* _tmp1;
+	char* _tmp0;
+	gboolean _tmp2;
 	gboolean first;
 	char* cheaders;
-	char* _tmp3;
+	char* _tmp8;
+	GeeCollection* base_types;
 	self = VALA_INTERFACE_WRITER (base);
-	g_return_if_fail (st == NULL || VALA_IS_STRUCT (st));
-	if (vala_code_node_get_source_reference (VALA_CODE_NODE (st)) != NULL && vala_source_file_get_pkg (vala_source_reference_get_file (vala_code_node_get_source_reference (VALA_CODE_NODE (st))))) {
+	g_return_if_fail (VALA_IS_STRUCT (st));
+	if (vala_symbol_get_external_package (VALA_SYMBOL (st))) {
 		return;
 	}
 	if (!vala_interface_writer_check_accessibility (self, VALA_SYMBOL (st))) {
 		return;
 	}
 	vala_interface_writer_write_indent (self);
+	vala_interface_writer_write_string (self, "[CCode (");
+	_tmp1 = NULL;
+	_tmp0 = NULL;
+	if ((_tmp2 = _vala_strcmp0 ((_tmp0 = vala_typesymbol_get_cname (VALA_TYPESYMBOL (st), FALSE)), (_tmp1 = vala_struct_get_default_cname (st))) != 0, (_tmp1 = (g_free (_tmp1), NULL)), (_tmp0 = (g_free (_tmp0), NULL)), _tmp2)) {
+		char* _tmp4;
+		char* _tmp3;
+		_tmp4 = NULL;
+		_tmp3 = NULL;
+		vala_interface_writer_write_string (self, (_tmp4 = g_strdup_printf ("cname = \"%s\", ", (_tmp3 = vala_typesymbol_get_cname (VALA_TYPESYMBOL (st), FALSE)))));
+		_tmp4 = (g_free (_tmp4), NULL);
+		_tmp3 = (g_free (_tmp3), NULL);
+	}
 	first = TRUE;
 	cheaders = NULL;
 	{
@@ -378,16 +394,16 @@ static void vala_interface_writer_real_visit_struct (ValaCodeVisitor* base, Vala
 			cheader = ((char*) gee_iterator_get (cheader_it));
 			{
 				if (first) {
-					char* _tmp1;
-					const char* _tmp0;
-					_tmp1 = NULL;
-					_tmp0 = NULL;
-					cheaders = (_tmp1 = (_tmp0 = cheader, (_tmp0 == NULL ? NULL : g_strdup (_tmp0))), (cheaders = (g_free (cheaders), NULL)), _tmp1);
+					char* _tmp6;
+					const char* _tmp5;
+					_tmp6 = NULL;
+					_tmp5 = NULL;
+					cheaders = (_tmp6 = (_tmp5 = cheader, (_tmp5 == NULL ? NULL : g_strdup (_tmp5))), (cheaders = (g_free (cheaders), NULL)), _tmp6);
 					first = FALSE;
 				} else {
-					char* _tmp2;
-					_tmp2 = NULL;
-					cheaders = (_tmp2 = g_strdup_printf ("%s,%s", cheaders, cheader), (cheaders = (g_free (cheaders), NULL)), _tmp2);
+					char* _tmp7;
+					_tmp7 = NULL;
+					cheaders = (_tmp7 = g_strdup_printf ("%s,%s", cheaders, cheader), (cheaders = (g_free (cheaders), NULL)), _tmp7);
 				}
 				cheader = (g_free (cheader), NULL);
 			}
@@ -395,9 +411,9 @@ static void vala_interface_writer_real_visit_struct (ValaCodeVisitor* base, Vala
 		(cheader_collection == NULL ? NULL : (cheader_collection = (g_object_unref (cheader_collection), NULL)));
 		(cheader_it == NULL ? NULL : (cheader_it = (g_object_unref (cheader_it), NULL)));
 	}
-	_tmp3 = NULL;
-	vala_interface_writer_write_string (self, (_tmp3 = g_strdup_printf ("[CCode (cheader_filename = \"%s\")]", cheaders)));
-	_tmp3 = (g_free (_tmp3), NULL);
+	_tmp8 = NULL;
+	vala_interface_writer_write_string (self, (_tmp8 = g_strdup_printf ("cheader_filename = \"%s\")]", cheaders)));
+	_tmp8 = (g_free (_tmp8), NULL);
 	vala_interface_writer_write_newline (self);
 	if (vala_struct_is_simple_type (st)) {
 		vala_interface_writer_write_indent (self);
@@ -408,11 +424,38 @@ static void vala_interface_writer_real_visit_struct (ValaCodeVisitor* base, Vala
 	vala_interface_writer_write_accessibility (self, VALA_SYMBOL (st));
 	vala_interface_writer_write_string (self, "struct ");
 	vala_interface_writer_write_identifier (self, vala_symbol_get_name (VALA_SYMBOL (st)));
+	base_types = vala_struct_get_base_types (st);
+	if (gee_collection_get_size (base_types) > 0) {
+		gboolean first;
+		vala_interface_writer_write_string (self, " : ");
+		first = TRUE;
+		{
+			GeeCollection* base_type_collection;
+			GeeIterator* base_type_it;
+			base_type_collection = base_types;
+			base_type_it = gee_iterable_iterator (GEE_ITERABLE (base_type_collection));
+			while (gee_iterator_next (base_type_it)) {
+				ValaDataType* base_type;
+				base_type = ((ValaDataType*) gee_iterator_get (base_type_it));
+				{
+					if (!first) {
+						vala_interface_writer_write_string (self, ", ");
+					} else {
+						first = FALSE;
+					}
+					vala_interface_writer_write_type (self, base_type);
+					(base_type == NULL ? NULL : (base_type = (g_object_unref (base_type), NULL)));
+				}
+			}
+			(base_type_it == NULL ? NULL : (base_type_it = (g_object_unref (base_type_it), NULL)));
+		}
+	}
 	vala_interface_writer_write_begin_block (self);
 	vala_code_node_accept_children (VALA_CODE_NODE (st), VALA_CODE_VISITOR (self));
 	vala_interface_writer_write_end_block (self);
 	vala_interface_writer_write_newline (self);
 	cheaders = (g_free (cheaders), NULL);
+	(base_types == NULL ? NULL : (base_types = (g_object_unref (base_types), NULL)));
 }
 
 
@@ -427,8 +470,8 @@ static void vala_interface_writer_real_visit_interface (ValaCodeVisitor* base, V
 	GeeCollection* type_params;
 	GeeCollection* prerequisites;
 	self = VALA_INTERFACE_WRITER (base);
-	g_return_if_fail (iface == NULL || VALA_IS_INTERFACE (iface));
-	if (vala_code_node_get_source_reference (VALA_CODE_NODE (iface)) != NULL && vala_source_file_get_pkg (vala_source_reference_get_file (vala_code_node_get_source_reference (VALA_CODE_NODE (iface))))) {
+	g_return_if_fail (VALA_IS_INTERFACE (iface));
+	if (vala_symbol_get_external_package (VALA_SYMBOL (iface))) {
 		return;
 	}
 	if (!vala_interface_writer_check_accessibility (self, VALA_SYMBOL (iface))) {
@@ -555,8 +598,8 @@ static void vala_interface_writer_real_visit_enum (ValaCodeVisitor* base, ValaEn
 	char* _tmp3;
 	char* _tmp6;
 	self = VALA_INTERFACE_WRITER (base);
-	g_return_if_fail (en == NULL || VALA_IS_ENUM (en));
-	if (vala_code_node_get_source_reference (VALA_CODE_NODE (en)) != NULL && vala_source_file_get_pkg (vala_source_reference_get_file (vala_code_node_get_source_reference (VALA_CODE_NODE (en))))) {
+	g_return_if_fail (VALA_IS_ENUM (en));
+	if (vala_symbol_get_external_package (VALA_SYMBOL (en))) {
 		return;
 	}
 	if (!vala_interface_writer_check_accessibility (self, VALA_SYMBOL (en))) {
@@ -677,8 +720,8 @@ static void vala_interface_writer_real_visit_error_domain (ValaCodeVisitor* base
 	char* _tmp4;
 	char* _tmp3;
 	self = VALA_INTERFACE_WRITER (base);
-	g_return_if_fail (edomain == NULL || VALA_IS_ERROR_DOMAIN (edomain));
-	if (vala_code_node_get_source_reference (VALA_CODE_NODE (edomain)) != NULL && vala_source_file_get_pkg (vala_source_reference_get_file (vala_code_node_get_source_reference (VALA_CODE_NODE (edomain))))) {
+	g_return_if_fail (VALA_IS_ERROR_DOMAIN (edomain));
+	if (vala_symbol_get_external_package (VALA_SYMBOL (edomain))) {
 		return;
 	}
 	if (!vala_interface_writer_check_accessibility (self, VALA_SYMBOL (edomain))) {
@@ -734,7 +777,7 @@ static void vala_interface_writer_real_visit_error_domain (ValaCodeVisitor* base
 static void vala_interface_writer_real_visit_error_code (ValaCodeVisitor* base, ValaErrorCode* ecode) {
 	ValaInterfaceWriter * self;
 	self = VALA_INTERFACE_WRITER (base);
-	g_return_if_fail (ecode == NULL || VALA_IS_ERROR_CODE (ecode));
+	g_return_if_fail (VALA_IS_ERROR_CODE (ecode));
 	vala_interface_writer_write_indent (self);
 	vala_interface_writer_write_identifier (self, vala_symbol_get_name (VALA_SYMBOL (ecode)));
 	vala_interface_writer_write_string (self, ",");
@@ -745,8 +788,8 @@ static void vala_interface_writer_real_visit_error_code (ValaCodeVisitor* base,
 static void vala_interface_writer_real_visit_constant (ValaCodeVisitor* base, ValaConstant* c) {
 	ValaInterfaceWriter * self;
 	self = VALA_INTERFACE_WRITER (base);
-	g_return_if_fail (c == NULL || VALA_IS_CONSTANT (c));
-	if (vala_code_node_get_source_reference (VALA_CODE_NODE (c)) != NULL && vala_source_file_get_pkg (vala_source_reference_get_file (vala_code_node_get_source_reference (VALA_CODE_NODE (c))))) {
+	g_return_if_fail (VALA_IS_CONSTANT (c));
+	if (vala_symbol_get_external_package (VALA_SYMBOL (c))) {
 		return;
 	}
 	if (!vala_interface_writer_check_accessibility (self, VALA_SYMBOL (c))) {
@@ -769,8 +812,8 @@ static void vala_interface_writer_real_visit_field (ValaCodeVisitor* base, ValaF
 	char* _tmp0;
 	gboolean _tmp2;
 	self = VALA_INTERFACE_WRITER (base);
-	g_return_if_fail (f == NULL || VALA_IS_FIELD (f));
-	if (vala_code_node_get_source_reference (VALA_CODE_NODE (f)) != NULL && vala_source_file_get_pkg (vala_source_reference_get_file (vala_code_node_get_source_reference (VALA_CODE_NODE (f))))) {
+	g_return_if_fail (VALA_IS_FIELD (f));
+	if (vala_symbol_get_external_package (VALA_SYMBOL (f))) {
 		return;
 	}
 	if (!vala_interface_writer_check_accessibility (self, VALA_SYMBOL (f))) {
@@ -807,7 +850,7 @@ static void vala_interface_writer_real_visit_field (ValaCodeVisitor* base, ValaF
 
 static void vala_interface_writer_write_error_domains (ValaInterfaceWriter* self, GeeCollection* error_domains) {
 	g_return_if_fail (VALA_IS_INTERFACE_WRITER (self));
-	g_return_if_fail (error_domains == NULL || GEE_IS_COLLECTION (error_domains));
+	g_return_if_fail (GEE_IS_COLLECTION (error_domains));
 	if (gee_collection_get_size (error_domains) > 0) {
 		gboolean first;
 		vala_interface_writer_write_string (self, " throws ");
@@ -846,7 +889,7 @@ static gboolean vala_interface_writer_float_equal (ValaInterfaceWriter* self, do
 static void vala_interface_writer_write_params (ValaInterfaceWriter* self, GeeCollection* params) {
 	gint i;
 	g_return_if_fail (VALA_IS_INTERFACE_WRITER (self));
-	g_return_if_fail (params == NULL || GEE_IS_COLLECTION (params));
+	g_return_if_fail (GEE_IS_COLLECTION (params));
 	vala_interface_writer_write_string (self, "(");
 	i = 1;
 	{
@@ -888,11 +931,11 @@ static void vala_interface_writer_write_params (ValaInterfaceWriter* self, GeeCo
 					vala_interface_writer_write_string (self, (_tmp2 = g_strdup_printf ("[CCode (%s)] ", ccode_params->str)));
 					_tmp2 = (g_free (_tmp2), NULL);
 				}
-				if (vala_data_type_get_is_ref (vala_formal_parameter_get_type_reference (param)) || vala_data_type_get_is_out (vala_formal_parameter_get_type_reference (param))) {
-					if (vala_data_type_get_is_ref (vala_formal_parameter_get_type_reference (param))) {
+				if (vala_formal_parameter_get_direction (param) != VALA_PARAMETER_DIRECTION_IN) {
+					if (vala_formal_parameter_get_direction (param) == VALA_PARAMETER_DIRECTION_REF) {
 						vala_interface_writer_write_string (self, "ref ");
 					} else {
-						if (vala_data_type_get_is_out (vala_formal_parameter_get_type_reference (param))) {
+						if (vala_formal_parameter_get_direction (param) == VALA_PARAMETER_DIRECTION_OUT) {
 							vala_interface_writer_write_string (self, "out ");
 						}
 					}
@@ -932,8 +975,8 @@ static void vala_interface_writer_real_visit_delegate (ValaCodeVisitor* base, Va
 	char* _tmp3;
 	GeeList* _tmp4;
 	self = VALA_INTERFACE_WRITER (base);
-	g_return_if_fail (cb == NULL || VALA_IS_DELEGATE (cb));
-	if (vala_code_node_get_source_reference (VALA_CODE_NODE (cb)) != NULL && vala_source_file_get_pkg (vala_source_reference_get_file (vala_code_node_get_source_reference (VALA_CODE_NODE (cb))))) {
+	g_return_if_fail (VALA_IS_DELEGATE (cb));
+	if (vala_symbol_get_external_package (VALA_SYMBOL (cb))) {
 		return;
 	}
 	if (!vala_interface_writer_check_accessibility (self, VALA_SYMBOL (cb))) {
@@ -974,7 +1017,7 @@ static void vala_interface_writer_real_visit_delegate (ValaCodeVisitor* base, Va
 	_tmp3 = (g_free (_tmp3), NULL);
 	vala_interface_writer_write_indent (self);
 	vala_interface_writer_write_accessibility (self, VALA_SYMBOL (cb));
-	if (!vala_delegate_get_instance (cb)) {
+	if (!vala_delegate_get_has_target (cb)) {
 		vala_interface_writer_write_string (self, "static ");
 	}
 	vala_interface_writer_write_string (self, "delegate ");
@@ -1003,8 +1046,8 @@ static void vala_interface_writer_real_visit_method (ValaCodeVisitor* base, Vala
 	GeeCollection* _tmp17;
 	GeeCollection* _tmp18;
 	self = VALA_INTERFACE_WRITER (base);
-	g_return_if_fail (m == NULL || VALA_IS_METHOD (m));
-	if (vala_code_node_get_source_reference (VALA_CODE_NODE (m)) != NULL && vala_source_file_get_pkg (vala_source_reference_get_file (vala_code_node_get_source_reference (VALA_CODE_NODE (m))))) {
+	g_return_if_fail (VALA_IS_METHOD (m));
+	if (vala_symbol_get_external_package (VALA_SYMBOL (m))) {
 		return;
 	}
 	/* don't write interface implementation unless it's an abstract or virtual method*/
@@ -1138,7 +1181,7 @@ static void vala_interface_writer_real_visit_method (ValaCodeVisitor* base, Vala
 		vala_interface_writer_write_string (self, " ");
 		(datatype == NULL ? NULL : (datatype = (g_object_unref (datatype), NULL)));
 	} else {
-		if (!vala_method_get_instance (m)) {
+		if (vala_method_get_binding (m) == MEMBER_BINDING_STATIC) {
 			vala_interface_writer_write_string (self, "static ");
 		} else {
 			if (vala_method_get_is_abstract (m)) {
@@ -1172,7 +1215,7 @@ static void vala_interface_writer_real_visit_method (ValaCodeVisitor* base, Vala
 static void vala_interface_writer_real_visit_creation_method (ValaCodeVisitor* base, ValaCreationMethod* m) {
 	ValaInterfaceWriter * self;
 	self = VALA_INTERFACE_WRITER (base);
-	g_return_if_fail (m == NULL || VALA_IS_CREATION_METHOD (m));
+	g_return_if_fail (VALA_IS_CREATION_METHOD (m));
 	vala_code_visitor_visit_method (VALA_CODE_VISITOR (self), VALA_METHOD (m));
 }
 
@@ -1180,7 +1223,7 @@ static void vala_interface_writer_real_visit_creation_method (ValaCodeVisitor* b
 static void vala_interface_writer_real_visit_property (ValaCodeVisitor* base, ValaProperty* prop) {
 	ValaInterfaceWriter * self;
 	self = VALA_INTERFACE_WRITER (base);
-	g_return_if_fail (prop == NULL || VALA_IS_PROPERTY (prop));
+	g_return_if_fail (VALA_IS_PROPERTY (prop));
 	if (!vala_interface_writer_check_accessibility (self, VALA_SYMBOL (prop)) || vala_property_get_overrides (prop) || vala_property_get_base_interface_property (prop) != NULL) {
 		return;
 	}
@@ -1228,7 +1271,7 @@ static void vala_interface_writer_real_visit_signal (ValaCodeVisitor* base, Vala
 	ValaInterfaceWriter * self;
 	GeeList* _tmp0;
 	self = VALA_INTERFACE_WRITER (base);
-	g_return_if_fail (sig == NULL || VALA_IS_SIGNAL (sig));
+	g_return_if_fail (VALA_IS_SIGNAL (sig));
 	if (!vala_interface_writer_check_accessibility (self, VALA_SYMBOL (sig))) {
 		return;
 	}
@@ -1267,6 +1310,7 @@ static void vala_interface_writer_write_indent (ValaInterfaceWriter* self) {
 
 static void vala_interface_writer_write_identifier (ValaInterfaceWriter* self, const char* s) {
 	g_return_if_fail (VALA_IS_INTERFACE_WRITER (self));
+	g_return_if_fail (s != NULL);
 	if (_vala_strcmp0 (s, "base") == 0 || _vala_strcmp0 (s, "break") == 0 || _vala_strcmp0 (s, "class") == 0 || _vala_strcmp0 (s, "construct") == 0 || _vala_strcmp0 (s, "delegate") == 0 || _vala_strcmp0 (s, "delete") == 0 || _vala_strcmp0 (s, "do") == 0 || _vala_strcmp0 (s, "foreach") == 0 || _vala_strcmp0 (s, "in") == 0 || _vala_strcmp0 (s, "interface") == 0 || _vala_strcmp0 (s, "lock") == 0 || _vala_strcmp0 (s, "namespace") == 0 || _vala_strcmp0 (s, "new") == 0 || _vala_strcmp0 (s, "out") == 0 || _vala_strcmp0 (s, "ref") == 0 || _vala_strcmp0 (s, "signal") == 0) {
 		fputc ('@', self->priv->stream);
 	}
@@ -1276,7 +1320,7 @@ static void vala_interface_writer_write_identifier (ValaInterfaceWriter* self, c
 
 static void vala_interface_writer_write_return_type (ValaInterfaceWriter* self, ValaDataType* type) {
 	g_return_if_fail (VALA_IS_INTERFACE_WRITER (self));
-	g_return_if_fail (type == NULL || VALA_IS_DATA_TYPE (type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (type));
 	if (vala_data_type_is_reference_type_or_type_parameter (type)) {
 		if (!vala_data_type_get_transfers_ownership (type)) {
 			vala_interface_writer_write_string (self, "weak ");
@@ -1289,7 +1333,7 @@ static void vala_interface_writer_write_return_type (ValaInterfaceWriter* self,
 static void vala_interface_writer_write_type (ValaInterfaceWriter* self, ValaDataType* type) {
 	char* _tmp0;
 	g_return_if_fail (VALA_IS_INTERFACE_WRITER (self));
-	g_return_if_fail (type == NULL || VALA_IS_DATA_TYPE (type));
+	g_return_if_fail (VALA_IS_DATA_TYPE (type));
 	_tmp0 = NULL;
 	vala_interface_writer_write_string (self, (_tmp0 = vala_code_node_to_string (VALA_CODE_NODE (type))));
 	_tmp0 = (g_free (_tmp0), NULL);
@@ -1298,6 +1342,7 @@ static void vala_interface_writer_write_type (ValaInterfaceWriter* self, ValaDat
 
 static void vala_interface_writer_write_string (ValaInterfaceWriter* self, const char* s) {
 	g_return_if_fail (VALA_IS_INTERFACE_WRITER (self));
+	g_return_if_fail (s != NULL);
 	fprintf (self->priv->stream, "%s", s);
 	self->priv->bol = FALSE;
 }
@@ -1333,7 +1378,7 @@ static void vala_interface_writer_write_end_block (ValaInterfaceWriter* self) {
 
 static gboolean vala_interface_writer_check_accessibility (ValaInterfaceWriter* self, ValaSymbol* sym) {
 	g_return_val_if_fail (VALA_IS_INTERFACE_WRITER (self), FALSE);
-	g_return_val_if_fail (sym == NULL || VALA_IS_SYMBOL (sym), FALSE);
+	g_return_val_if_fail (VALA_IS_SYMBOL (sym), FALSE);
 	if (vala_symbol_get_access (sym) == VALA_SYMBOL_ACCESSIBILITY_PUBLIC || vala_symbol_get_access (sym) == VALA_SYMBOL_ACCESSIBILITY_PROTECTED) {
 		return TRUE;
 	}
@@ -1343,7 +1388,7 @@ static gboolean vala_interface_writer_check_accessibility (ValaInterfaceWriter*
 
 static void vala_interface_writer_write_accessibility (ValaInterfaceWriter* self, ValaSymbol* sym) {
 	g_return_if_fail (VALA_IS_INTERFACE_WRITER (self));
-	g_return_if_fail (sym == NULL || VALA_IS_SYMBOL (sym));
+	g_return_if_fail (VALA_IS_SYMBOL (sym));
 	if (vala_symbol_get_access (sym) == VALA_SYMBOL_ACCESSIBILITY_PUBLIC) {
 		vala_interface_writer_write_string (self, "public ");
 	} else {
