@@ -33,6 +33,7 @@ struct _ValaLockStatementPrivate {
 	ValaExpression* _resource;
 	ValaBlock* _body;
 };
+
 #define VALA_LOCK_STATEMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_LOCK_STATEMENT, ValaLockStatementPrivate))
 enum  {
 	VALA_LOCK_STATEMENT_DUMMY_PROPERTY,
@@ -50,19 +51,19 @@ ValaLockStatement* vala_lock_statement_new (ValaExpression* resource, ValaBlock*
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaLockStatement * self;
-	g_return_val_if_fail (resource == NULL || VALA_IS_EXPRESSION (resource), NULL);
-	g_return_val_if_fail (body == NULL || VALA_IS_BLOCK (body), NULL);
+	g_return_val_if_fail (VALA_IS_EXPRESSION (resource), NULL);
+	g_return_val_if_fail (VALA_IS_BLOCK (body), NULL);
 	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	__params = g_new0 (GParameter, 2);
 	__params_it = __params;
-	__params_it->name = "resource";
-	g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION);
-	g_value_set_object (&__params_it->value, resource);
-	__params_it++;
 	__params_it->name = "body";
 	g_value_init (&__params_it->value, VALA_TYPE_BLOCK);
 	g_value_set_object (&__params_it->value, body);
 	__params_it++;
+	__params_it->name = "resource";
+	g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION);
+	g_value_set_object (&__params_it->value, resource);
+	__params_it++;
 	self = g_object_newv (VALA_TYPE_LOCK_STATEMENT, __params_it - __params, __params);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
 	while (__params_it > __params) {
@@ -77,7 +78,7 @@ ValaLockStatement* vala_lock_statement_new (ValaExpression* resource, ValaBlock*
 static void vala_lock_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaLockStatement * self;
 	self = VALA_LOCK_STATEMENT (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (self->priv->_resource), visitor);
 	vala_code_node_accept (VALA_CODE_NODE (self->priv->_body), visitor);
 	vala_code_visitor_visit_lock_statement (visitor, self);
