@@ -30,6 +30,7 @@
 struct _ValaParenthesizedExpressionPrivate {
 	ValaExpression* _inner;
 };
+
 #define VALA_PARENTHESIZED_EXPRESSION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_PARENTHESIZED_EXPRESSION, ValaParenthesizedExpressionPrivate))
 enum  {
 	VALA_PARENTHESIZED_EXPRESSION_DUMMY_PROPERTY,
@@ -55,7 +56,7 @@ ValaParenthesizedExpression* vala_parenthesized_expression_new (ValaExpression*
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaParenthesizedExpression * self;
-	g_return_val_if_fail (_inner == NULL || VALA_IS_EXPRESSION (_inner), NULL);
+	g_return_val_if_fail (VALA_IS_EXPRESSION (_inner), NULL);
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
@@ -77,7 +78,7 @@ ValaParenthesizedExpression* vala_parenthesized_expression_new (ValaExpression*
 static void vala_parenthesized_expression_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaParenthesizedExpression * self;
 	self = VALA_PARENTHESIZED_EXPRESSION (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_parenthesized_expression (visitor, self);
 }
 
@@ -85,7 +86,7 @@ static void vala_parenthesized_expression_real_accept (ValaCodeNode* base, ValaC
 static void vala_parenthesized_expression_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaParenthesizedExpression * self;
 	self = VALA_PARENTHESIZED_EXPRESSION (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_parenthesized_expression_get_inner (self)), visitor);
 }
 
@@ -93,8 +94,8 @@ static void vala_parenthesized_expression_real_accept_children (ValaCodeNode* ba
 static void vala_parenthesized_expression_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node) {
 	ValaParenthesizedExpression * self;
 	self = VALA_PARENTHESIZED_EXPRESSION (base);
-	g_return_if_fail (old_node == NULL || VALA_IS_EXPRESSION (old_node));
-	g_return_if_fail (new_node == NULL || VALA_IS_EXPRESSION (new_node));
+	g_return_if_fail (VALA_IS_EXPRESSION (old_node));
+	g_return_if_fail (VALA_IS_EXPRESSION (new_node));
 	if (vala_parenthesized_expression_get_inner (self) == old_node) {
 		vala_parenthesized_expression_set_inner (self, new_node);
 	}
