@@ -22,9 +22,13 @@
 
 #include <vala/valasignaltype.h>
 
+
+
+
 struct _ValaSignalTypePrivate {
 	ValaSignal* _signal_symbol;
 };
+
 #define VALA_SIGNAL_TYPE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_SIGNAL_TYPE, ValaSignalTypePrivate))
 enum  {
 	VALA_SIGNAL_TYPE_DUMMY_PROPERTY,
@@ -38,9 +42,10 @@ static gpointer vala_signal_type_parent_class = NULL;
 static void vala_signal_type_dispose (GObject * obj);
 
 
+
 ValaSignalType* vala_signal_type_new (ValaSignal* signal_symbol) {
 	ValaSignalType * self;
-	g_return_val_if_fail (signal_symbol == NULL || VALA_IS_SIGNAL (signal_symbol), NULL);
+	g_return_val_if_fail (VALA_IS_SIGNAL (signal_symbol), NULL);
 	self = g_object_newv (VALA_TYPE_SIGNAL_TYPE, 0, NULL);
 	vala_signal_type_set_signal_symbol (self, signal_symbol);
 	return self;
@@ -59,21 +64,21 @@ static ValaDataType* vala_signal_type_real_get_return_type (ValaDataType* base)
 	ValaDataType* _tmp0;
 	self = VALA_SIGNAL_TYPE (base);
 	_tmp0 = NULL;
-	return (_tmp0 = vala_signal_get_return_type (vala_signal_type_get_signal_symbol (self)), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
+	return (_tmp0 = vala_signal_get_return_type (self->priv->_signal_symbol), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
 }
 
 
 static GeeCollection* vala_signal_type_real_get_parameters (ValaDataType* base) {
 	ValaSignalType * self;
 	self = VALA_SIGNAL_TYPE (base);
-	return GEE_COLLECTION (vala_signal_get_parameters (vala_signal_type_get_signal_symbol (self)));
+	return GEE_COLLECTION (vala_signal_get_parameters (self->priv->_signal_symbol));
 }
 
 
 static ValaDataType* vala_signal_type_real_copy (ValaDataType* base) {
 	ValaSignalType * self;
 	self = VALA_SIGNAL_TYPE (base);
-	return VALA_DATA_TYPE (vala_signal_type_new (vala_signal_type_get_signal_symbol (self)));
+	return VALA_DATA_TYPE (vala_signal_type_new (self->priv->_signal_symbol));
 }
 
 
