@@ -1,6 +1,6 @@
 /* valasourcereference.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2008  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -34,6 +34,7 @@ struct _ValaSourceReferencePrivate {
 	gint _last_column;
 	char* _comment;
 };
+
 #define VALA_SOURCE_REFERENCE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_SOURCE_REFERENCE, ValaSourceReferencePrivate))
 enum  {
 	VALA_SOURCE_REFERENCE_DUMMY_PROPERTY,
@@ -61,7 +62,7 @@ static void vala_source_reference_dispose (GObject * obj);
  */
 ValaSourceReference* vala_source_reference_new (ValaSourceFile* _file, gint _first_line, gint _first_column, gint _last_line, gint _last_column) {
 	ValaSourceReference * self;
-	g_return_val_if_fail (_file == NULL || VALA_IS_SOURCE_FILE (_file), NULL);
+	g_return_val_if_fail (VALA_IS_SOURCE_FILE (_file), NULL);
 	self = g_object_newv (VALA_TYPE_SOURCE_REFERENCE, 0, NULL);
 	vala_source_reference_set_file (self, _file);
 	vala_source_reference_set_first_line (self, _first_line);
@@ -85,7 +86,7 @@ ValaSourceReference* vala_source_reference_new (ValaSourceFile* _file, gint _fir
  */
 ValaSourceReference* vala_source_reference_new_with_comment (ValaSourceFile* _file, gint _first_line, gint _first_column, gint _last_line, gint _last_column, const char* _comment) {
 	ValaSourceReference * self;
-	g_return_val_if_fail (_file == NULL || VALA_IS_SOURCE_FILE (_file), NULL);
+	g_return_val_if_fail (VALA_IS_SOURCE_FILE (_file), NULL);
 	self = g_object_newv (VALA_TYPE_SOURCE_REFERENCE, 0, NULL);
 	vala_source_reference_set_file (self, _file);
 	vala_source_reference_set_first_line (self, _first_line);
