@@ -30,6 +30,7 @@
 struct _ValaStringLiteralPrivate {
 	char* _value;
 };
+
 #define VALA_STRING_LITERAL_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_STRING_LITERAL, ValaStringLiteralPrivate))
 enum  {
 	VALA_STRING_LITERAL_DUMMY_PROPERTY,
@@ -37,6 +38,7 @@ enum  {
 };
 static void vala_string_literal_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
 static gboolean vala_string_literal_real_is_pure (ValaExpression* base);
+static char* vala_string_literal_real_to_string (ValaCodeNode* base);
 static gpointer vala_string_literal_parent_class = NULL;
 static void vala_string_literal_dispose (GObject * obj);
 
@@ -51,7 +53,8 @@ static void vala_string_literal_dispose (GObject * obj);
  */
 ValaStringLiteral* vala_string_literal_new (const char* s, ValaSourceReference* source) {
 	ValaStringLiteral * self;
-	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
+	g_return_val_if_fail (s != NULL, NULL);
+	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source), NULL);
 	self = g_object_newv (VALA_TYPE_STRING_LITERAL, 0, NULL);
 	vala_string_literal_set_value (self, s);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source);
@@ -73,16 +76,16 @@ char* vala_string_literal_eval (ValaStringLiteral* self) {
 	}
 	/* remove quotes */
 	noquotes = g_strndup (g_utf8_offset_to_pointer (self->priv->_value, ((glong) 1)), ((gulong) ((guint) (g_utf8_strlen (self->priv->_value, -1) - 2))));
+	/* unescape string */
 	_tmp1 = NULL;
 	return (_tmp1 = g_strcompress (noquotes), (noquotes = (g_free (noquotes), NULL)), _tmp1);
 }
 
 
-/* unescape string */
 static void vala_string_literal_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaStringLiteral * self;
 	self = VALA_STRING_LITERAL (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_visitor_visit_string_literal (visitor, self);
 }
 
@@ -94,6 +97,15 @@ static gboolean vala_string_literal_real_is_pure (ValaExpression* base) {
 }
 
 
+static char* vala_string_literal_real_to_string (ValaCodeNode* base) {
+	ValaStringLiteral * self;
+	const char* _tmp0;
+	self = VALA_STRING_LITERAL (base);
+	_tmp0 = NULL;
+	return (_tmp0 = self->priv->_value, (_tmp0 == NULL ? NULL : g_strdup (_tmp0)));
+}
+
+
 char* vala_string_literal_get_value (ValaStringLiteral* self) {
 	g_return_val_if_fail (VALA_IS_STRING_LITERAL (self), NULL);
 	return self->priv->_value;
@@ -146,6 +158,7 @@ static void vala_string_literal_class_init (ValaStringLiteralClass * klass) {
 	G_OBJECT_CLASS (klass)->dispose = vala_string_literal_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_string_literal_real_accept;
 	VALA_EXPRESSION_CLASS (klass)->is_pure = vala_string_literal_real_is_pure;
+	VALA_CODE_NODE_CLASS (klass)->to_string = vala_string_literal_real_to_string;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_STRING_LITERAL_VALUE, g_param_spec_string ("value", "value", "value", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
