@@ -29,10 +29,14 @@
 #include <vala/valasourcereference.h>
 #include <vala/valacodevisitor.h>
 
+
+
+
 struct _ValaSwitchStatementPrivate {
 	ValaExpression* _expression;
 	GeeList* sections;
 };
+
 #define VALA_SWITCH_STATEMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_SWITCH_STATEMENT, ValaSwitchStatementPrivate))
 enum  {
 	VALA_SWITCH_STATEMENT_DUMMY_PROPERTY,
@@ -45,6 +49,7 @@ static ValaStatementIface* vala_switch_statement_vala_statement_parent_iface = N
 static void vala_switch_statement_dispose (GObject * obj);
 
 
+
 /**
  * Creates a new switch statement.
  *
@@ -56,11 +61,14 @@ ValaSwitchStatement* vala_switch_statement_new (ValaExpression* expression, Vala
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaSwitchStatement * self;
-	g_return_val_if_fail (expression == NULL || VALA_IS_EXPRESSION (expression), NULL);
-	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
+	g_return_val_if_fail (VALA_IS_EXPRESSION (expression), NULL);
+	g_return_val_if_fail (VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
 	__params = g_new0 (GParameter, 1);
 	__params_it = __params;
-	(__params_it->name = "expression", g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION), g_value_set_object (&__params_it->value, expression), __params_it++);
+	__params_it->name = "expression";
+	g_value_init (&__params_it->value, VALA_TYPE_EXPRESSION);
+	g_value_set_object (&__params_it->value, expression);
+	__params_it++;
 	self = g_object_newv (VALA_TYPE_SWITCH_STATEMENT, __params_it - __params, __params);
 	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
 	while (__params_it > __params) {
@@ -79,7 +87,7 @@ ValaSwitchStatement* vala_switch_statement_new (ValaExpression* expression, Vala
  */
 void vala_switch_statement_add_section (ValaSwitchStatement* self, ValaSwitchSection* section) {
 	g_return_if_fail (VALA_IS_SWITCH_STATEMENT (self));
-	g_return_if_fail (section == NULL || VALA_IS_SWITCH_SECTION (section));
+	g_return_if_fail (VALA_IS_SWITCH_SECTION (section));
 	vala_code_node_set_parent_node (VALA_CODE_NODE (section), VALA_CODE_NODE (self));
 	gee_collection_add (GEE_COLLECTION (self->priv->sections), section);
 }
@@ -99,7 +107,7 @@ GeeCollection* vala_switch_statement_get_sections (ValaSwitchStatement* self) {
 static void vala_switch_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaSwitchStatement * self;
 	self = VALA_SWITCH_STATEMENT (base);
-	g_return_if_fail (visitor == NULL || VALA_IS_CODE_VISITOR (visitor));
+	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	vala_code_node_accept (VALA_CODE_NODE (vala_switch_statement_get_expression (self)), visitor);
 	vala_code_visitor_visit_end_full_expression (visitor, vala_switch_statement_get_expression (self));
 	{
@@ -109,7 +117,7 @@ static void vala_switch_statement_real_accept (ValaCodeNode* base, ValaCodeVisit
 		section_it = gee_iterable_iterator (GEE_ITERABLE (section_collection));
 		while (gee_iterator_next (section_it)) {
 			ValaSwitchSection* section;
-			section = gee_iterator_get (section_it);
+			section = ((ValaSwitchSection*) gee_iterator_get (section_it));
 			{
 				vala_code_node_accept (VALA_CODE_NODE (section), visitor);
 				(section == NULL ? NULL : (section = (g_object_unref (section), NULL)));
@@ -124,8 +132,8 @@ static void vala_switch_statement_real_accept (ValaCodeNode* base, ValaCodeVisit
 static void vala_switch_statement_real_replace_expression (ValaCodeNode* base, ValaExpression* old_node, ValaExpression* new_node) {
 	ValaSwitchStatement * self;
 	self = VALA_SWITCH_STATEMENT (base);
-	g_return_if_fail (old_node == NULL || VALA_IS_EXPRESSION (old_node));
-	g_return_if_fail (new_node == NULL || VALA_IS_EXPRESSION (new_node));
+	g_return_if_fail (VALA_IS_EXPRESSION (old_node));
+	g_return_if_fail (VALA_IS_EXPRESSION (new_node));
 	if (vala_switch_statement_get_expression (self) == old_node) {
 		vala_switch_statement_set_expression (self, new_node);
 	}
