@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,14 +20,14 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALASWITCHSTATEMENT_H__
-#define __VALASWITCHSTATEMENT_H__
-typedef struct _ValaSwitchStatementPrivate ValaSwitchStatementPrivate;
+#ifndef __VALA_VALASWITCHSTATEMENT_H__
+#define __VALA_VALASWITCHSTATEMENT_H__
 
 #include <glib.h>
 #include <glib-object.h>
-#include <vala/valastatement.h>
+#include <gee/collection.h>
 #include <vala/valacodenode.h>
+#include <vala/valastatement.h>
 
 G_BEGIN_DECLS
 
@@ -39,24 +39,28 @@ G_BEGIN_DECLS
 #define VALA_IS_SWITCH_STATEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_SWITCH_STATEMENT))
 #define VALA_SWITCH_STATEMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_SWITCH_STATEMENT, ValaSwitchStatementClass))
 
+typedef struct _ValaSwitchStatementPrivate ValaSwitchStatementPrivate;
 
 /**
  * Represents a switch selection statement in the source code.
  */
 struct _ValaSwitchStatement {
-	ValaStatement parent;
+	ValaCodeNode parent_instance;
 	ValaSwitchStatementPrivate * priv;
 };
+
 struct _ValaSwitchStatementClass {
-	ValaStatementClass parent;
+	ValaCodeNodeClass parent_class;
 };
 
-ValaSwitchStatement* vala_switch_statement_new (ValaExpression* expr, ValaSourceReference* source);
+
+ValaSwitchStatement* vala_switch_statement_new (ValaExpression* expression, ValaSourceReference* source_reference);
 void vala_switch_statement_add_section (ValaSwitchStatement* self, ValaSwitchSection* section);
-GList* vala_switch_statement_get_sections (ValaSwitchStatement* self);
+GeeCollection* vala_switch_statement_get_sections (ValaSwitchStatement* self);
 ValaExpression* vala_switch_statement_get_expression (ValaSwitchStatement* self);
 void vala_switch_statement_set_expression (ValaSwitchStatement* self, ValaExpression* value);
-GType vala_switch_statement_get_type ();
+GType vala_switch_statement_get_type (void);
+
 
 G_END_DECLS
 
