@@ -22,8 +22,6 @@
  */
 
 #include <vala/valaunresolvedtype.h>
-#include <stdlib.h>
-#include <string.h>
 #include <gee/collection.h>
 #include <vala/valacodenode.h>
 #include <vala/valamemberaccess.h>
@@ -38,6 +36,7 @@ struct _ValaUnresolvedTypePrivate {
 	gint _pointer_level;
 	gboolean _is_weak;
 };
+
 #define VALA_UNRESOLVED_TYPE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_UNRESOLVED_TYPE, ValaUnresolvedTypePrivate))
 enum  {
 	VALA_UNRESOLVED_TYPE_DUMMY_PROPERTY,
@@ -47,6 +46,7 @@ enum  {
 	VALA_UNRESOLVED_TYPE_IS_WEAK
 };
 static ValaDataType* vala_unresolved_type_real_copy (ValaDataType* base);
+static char* vala_unresolved_type_real_to_string (ValaCodeNode* base);
 static gpointer vala_unresolved_type_parent_class = NULL;
 static void vala_unresolved_type_dispose (GObject * obj);
 
@@ -68,7 +68,7 @@ ValaUnresolvedType* vala_unresolved_type_new (void) {
  */
 ValaUnresolvedType* vala_unresolved_type_new_from_symbol (ValaUnresolvedSymbol* symbol, ValaSourceReference* source) {
 	ValaUnresolvedType * self;
-	g_return_val_if_fail (symbol == NULL || VALA_IS_UNRESOLVED_SYMBOL (symbol), NULL);
+	g_return_val_if_fail (VALA_IS_UNRESOLVED_SYMBOL (symbol), NULL);
 	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
 	self = g_object_newv (VALA_TYPE_UNRESOLVED_TYPE, 0, NULL);
 	vala_unresolved_type_set_unresolved_symbol (self, symbol);
@@ -88,7 +88,7 @@ ValaUnresolvedType* vala_unresolved_type_new_from_expression (ValaExpression* ex
 	char* ns;
 	char* type_name;
 	gpointer _tmp8;
-	g_return_val_if_fail (expr == NULL || VALA_IS_EXPRESSION (expr), NULL);
+	g_return_val_if_fail (VALA_IS_EXPRESSION (expr), NULL);
 	ns = NULL;
 	type_name = NULL;
 	if (VALA_IS_MEMBER_ACCESS (expr)) {
@@ -162,15 +162,13 @@ static ValaDataType* vala_unresolved_type_real_copy (ValaDataType* base) {
 	vala_code_node_set_source_reference (VALA_CODE_NODE (result), vala_code_node_get_source_reference (VALA_CODE_NODE (self)));
 	vala_data_type_set_transfers_ownership (VALA_DATA_TYPE (result), vala_data_type_get_transfers_ownership (VALA_DATA_TYPE (self)));
 	vala_data_type_set_takes_ownership (VALA_DATA_TYPE (result), vala_data_type_get_takes_ownership (VALA_DATA_TYPE (self)));
-	vala_data_type_set_is_out (VALA_DATA_TYPE (result), vala_data_type_get_is_out (VALA_DATA_TYPE (self)));
 	vala_data_type_set_nullable (VALA_DATA_TYPE (result), vala_data_type_get_nullable (VALA_DATA_TYPE (self)));
-	vala_data_type_set_requires_null_check (VALA_DATA_TYPE (result), vala_data_type_get_requires_null_check (VALA_DATA_TYPE (self)));
+	vala_data_type_set_is_dynamic (VALA_DATA_TYPE (result), vala_data_type_get_is_dynamic (VALA_DATA_TYPE (self)));
 	_tmp0 = NULL;
 	vala_unresolved_type_set_unresolved_symbol (result, (_tmp0 = vala_unresolved_symbol_copy (self->priv->_unresolved_symbol)));
 	(_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL)));
 	vala_unresolved_type_set_array_rank (result, self->priv->_array_rank);
 	vala_unresolved_type_set_pointer_level (result, self->priv->_pointer_level);
-	vala_data_type_set_is_ref (VALA_DATA_TYPE (result), vala_data_type_get_is_ref (VALA_DATA_TYPE (self)));
 	vala_unresolved_type_set_is_weak (result, self->priv->_is_weak);
 	{
 		GeeList* arg_collection;
@@ -195,6 +193,13 @@ static ValaDataType* vala_unresolved_type_real_copy (ValaDataType* base) {
 }
 
 
+static char* vala_unresolved_type_real_to_string (ValaCodeNode* base) {
+	ValaUnresolvedType * self;
+	self = VALA_UNRESOLVED_TYPE (base);
+	return vala_code_node_to_string (VALA_CODE_NODE (self->priv->_unresolved_symbol));
+}
+
+
 ValaUnresolvedSymbol* vala_unresolved_type_get_unresolved_symbol (ValaUnresolvedType* self) {
 	g_return_val_if_fail (VALA_IS_UNRESOLVED_TYPE (self), NULL);
 	return self->priv->_unresolved_symbol;
@@ -300,6 +305,7 @@ static void vala_unresolved_type_class_init (ValaUnresolvedTypeClass * klass) {
 	G_OBJECT_CLASS (klass)->set_property = vala_unresolved_type_set_property;
 	G_OBJECT_CLASS (klass)->dispose = vala_unresolved_type_dispose;
 	VALA_DATA_TYPE_CLASS (klass)->copy = vala_unresolved_type_real_copy;
+	VALA_CODE_NODE_CLASS (klass)->to_string = vala_unresolved_type_real_to_string;
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_UNRESOLVED_TYPE_UNRESOLVED_SYMBOL, g_param_spec_object ("unresolved-symbol", "unresolved-symbol", "unresolved-symbol", VALA_TYPE_UNRESOLVED_SYMBOL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_UNRESOLVED_TYPE_ARRAY_RANK, g_param_spec_int ("array-rank", "array-rank", "array-rank", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_UNRESOLVED_TYPE_POINTER_LEVEL, g_param_spec_int ("pointer-level", "pointer-level", "pointer-level", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
