@@ -54,11 +54,13 @@ struct _ValaVAPICheck {
 	GObject parent_instance;
 	ValaVAPICheckPrivate * priv;
 };
+
 struct _ValaVAPICheckClass {
 	GObjectClass parent_class;
 };
 
 
+
 struct _ValaVAPICheckPrivate {
 	ValaCodeContext* _context;
 	ValaSourceFile* _gidl;
@@ -66,6 +68,7 @@ struct _ValaVAPICheckPrivate {
 	GeeList* _scope;
 	GeeSet* _symbols;
 };
+
 #define VALA_VAPI_CHECK_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_VAPI_CHECK, ValaVAPICheckPrivate))
 enum  {
 	VALA_VAPI_CHECK_DUMMY_PROPERTY,
@@ -74,6 +77,7 @@ enum  {
 	VALA_VAPI_CHECK_METADATA
 };
 static ValaVAPICheck* vala_vapi_check_new (const char* gidlname, ValaCodeContext* context);
+static void _g_list_free_g_idl_module_free (GList* self);
 static void vala_vapi_check_parse_gidl (ValaVAPICheck* self);
 static void vala_vapi_check_add_symbol (ValaVAPICheck* self, const char* name, const char* separator);
 static char* vala_vapi_check_get_scope (ValaVAPICheck* self);
@@ -105,7 +109,8 @@ static ValaVAPICheck* vala_vapi_check_new (const char* gidlname, ValaCodeContext
 	char* _tmp2;
 	char* _tmp1;
 	ValaVAPICheck * self;
-	g_return_val_if_fail (context == NULL || VALA_IS_CODE_CONTEXT (context), NULL);
+	g_return_val_if_fail (gidlname != NULL, NULL);
+	g_return_val_if_fail (VALA_IS_CODE_CONTEXT (context), NULL);
 	__params = g_new0 (GParameter, 3);
 	__params_it = __params;
 	_tmp0 = NULL;
@@ -139,6 +144,12 @@ static ValaVAPICheck* vala_vapi_check_new (const char* gidlname, ValaCodeContext
 }
 
 
+static void _g_list_free_g_idl_module_free (GList* self) {
+	g_list_foreach (self, ((GFunc) g_idl_module_free), NULL);
+	g_list_free (self);
+}
+
+
 static void vala_vapi_check_parse_gidl (ValaVAPICheck* self) {
 	GError * inner_error;
 	GeeList* _tmp0;
@@ -168,7 +179,7 @@ static void vala_vapi_check_parse_gidl (ValaVAPICheck* self) {
 					vala_vapi_check_parse_members (self, module->name, module->entries);
 				}
 			}
-			(module_collection == NULL ? NULL : (module_collection = (g_list_foreach (module_collection, ((GFunc) g_idl_module_free), NULL), g_list_free (module_collection), NULL)));
+			(module_collection == NULL ? NULL : (module_collection = (_g_list_free_g_idl_module_free (module_collection), NULL)));
 		}
 	}
 	goto __finally0;
@@ -188,6 +199,7 @@ static void vala_vapi_check_parse_gidl (ValaVAPICheck* self) {
 
 static void vala_vapi_check_add_symbol (ValaVAPICheck* self, const char* name, const char* separator) {
 	g_return_if_fail (VALA_IS_VAPI_CHECK (self));
+	g_return_if_fail (name != NULL);
 	if (NULL != separator) {
 		char* _tmp1;
 		char* _tmp0;
@@ -213,6 +225,7 @@ static char* vala_vapi_check_get_scope (ValaVAPICheck* self) {
 
 static void vala_vapi_check_enter_scope (ValaVAPICheck* self, const char* name) {
 	g_return_if_fail (VALA_IS_VAPI_CHECK (self));
+	g_return_if_fail (name != NULL);
 	gee_collection_add (GEE_COLLECTION (self->priv->_scope), name);
 	vala_vapi_check_add_symbol (self, name, NULL);
 }
@@ -226,6 +239,8 @@ static void vala_vapi_check_leave_scope (ValaVAPICheck* self) {
 
 static void vala_vapi_check_parse_members (ValaVAPICheck* self, const char* name, GList* members) {
 	g_return_if_fail (VALA_IS_VAPI_CHECK (self));
+	g_return_if_fail (name != NULL);
+	g_return_if_fail (members != NULL);
 	vala_vapi_check_enter_scope (self, name);
 	{
 		GList* node_collection;
@@ -270,7 +285,7 @@ static void vala_vapi_check_parse_members (ValaVAPICheck* self, const char* name
 					break;
 				} while (0); else
 				do {
-					g_warning ("valavapicheck.vala:120: TODO: %s: Implement support for type %d nodes", node->name, node->type);
+					g_warning ("valavapicheck.vala:121: TODO: %s: Implement support for type %d nodes", node->name, node->type);
 					break;
 				} while (0);
 			}
